(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    248244,       4123]*)
(*NotebookOutlinePosition[    249025,       4152]*)
(*  CellTagsIndexPosition[    248950,       4146]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Methoden der Bioinformatik",
    FontSize->24,
    FontWeight->"Bold"],
  StyleBox[" \n",
    FontSize->12],
  StyleBox["Eine Einf\[UDoubleDot]hrung",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Marc-Thorsten H\[UDoubleDot]tt und Manuel Dehnert",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Springer-Verlag 2006 (ISBN 3-540-25687-3)",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12]
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs: ",
  "Small-World-Modell"
}], "Subtitle",
  Background->RGBColor[0.0901961, 0.462745, 0.396078]],

Cell[TextData[{
  "Das ",
  StyleBox["Combinatorica",
    FontSlant->"Italic"],
  "-Paket von ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " stellt eine interessante Visualisierung- und Analyseumgebung f\
\[UDoubleDot]r Graphen dar. Wir werden in diesem ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs die Erzeugung und Analyse von Small-World-Graphen, die von Watts \
und Strogatz (1998) eingef\[UDoubleDot]hrt worden sind, nachzeichnen. \n\nWie \
wir gesehen haben, ben\[ODoubleDot]tigen wir dazu zuerst eine Routine, die \
regul\[ADoubleDot]re Graphen als Ausgangspunkt f\[UDoubleDot]r die Erzeugung \
von Small-World-Graphen bereitstellt. Ein solcher regul\[ADoubleDot]rer \
\"backbone\"-Graph besteht aus einer Kette von ",
  StyleBox["N",
    FontSlant->"Italic"],
  " Knoten, die mit ihren ",
  StyleBox["k",
    FontSlant->"Italic"],
  " Nachbarn in jede Richtung verbunden sind. Wir diskutieren an dieser \
Stelle ausschlie\[SZ]lich ungerichtete Graphen. Ebenso beziehen wir keine \
Gewichte (also quantitative Zuweisungen von Bedeutung an den Kanten des \
Graphen) mit ein. Solche Bildungsgesetze eines Graphen lassen sich in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " fast immer sowohl auf der Ebene des Graphen selbst, als auch auf der \
Ebene der Adjacency-Matrix formulieren. Betrachten wir zun\[ADoubleDot]chst \
einen einfachen Zufallsgraphen, um uns an die entsprechenden Befehle in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " zu gew\[ODoubleDot]hnen. Die Erzeugung geschieht mit dem Befehl ",
  StyleBox["RandomGraph[N, p]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", wobei ",
  StyleBox["N",
    FontSlant->"Italic"],
  " die Zahl der Knoten und der Parameter ",
  StyleBox["p",
    FontSlant->"Italic"],
  " die Wahrscheinlichkeit f\[UDoubleDot]r eine Verbindung angibt."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(SeedRandom[3];\)\)], "Input"],

Cell["<<DiscreteMath`Combinatorica`", "Input",
  CellTags->"S5.20.1"],

Cell[BoxData[
    \(\(g1 = RandomGraph[10, 0.7];\)\)], "Input"],

Cell[TextData[{
  "Die Darstellung erfolgt mit dem Befehl ",
  StyleBox["ShowGraph[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pl0 = ShowGraph[g1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.909091 0.0242882 0.951424 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.005 w
[ ] 0 setdash
.86773 .77962 m
.35954 .95243 L
s
.86773 .77962 m
.13227 .77962 L
s
.86773 .77962 m
.64046 .04757 L
s
.86773 .77962 m
.95455 .5 L
s
.64046 .95243 m
.13227 .77962 L
s
.64046 .95243 m
.13227 .22038 L
s
.64046 .95243 m
.35954 .04757 L
s
.64046 .95243 m
.86773 .22038 L
s
.64046 .95243 m
.95455 .5 L
s
.35954 .95243 m
.13227 .77962 L
s
.35954 .95243 m
.04545 .5 L
s
.35954 .95243 m
.35954 .04757 L
s
.35954 .95243 m
.64046 .04757 L
s
.35954 .95243 m
.86773 .22038 L
s
.35954 .95243 m
.95455 .5 L
s
.13227 .77962 m
.04545 .5 L
s
.13227 .77962 m
.13227 .22038 L
s
.13227 .77962 m
.35954 .04757 L
s
.13227 .77962 m
.64046 .04757 L
s
.04545 .5 m
.13227 .22038 L
s
.04545 .5 m
.64046 .04757 L
s
.13227 .22038 m
.86773 .22038 L
s
.35954 .04757 m
.64046 .04757 L
s
.35954 .04757 m
.86773 .22038 L
s
.35954 .04757 m
.95455 .5 L
s
.64046 .04757 m
.86773 .22038 L
s
.64046 .04757 m
.95455 .5 L
s
.025 w
.86773 .77962 Mdot
.64046 .95243 Mdot
.35954 .95243 Mdot
.13227 .77962 Mdot
.04545 .5 Mdot
.13227 .22038 Mdot
.35954 .04757 Mdot
.64046 .04757 Mdot
.86773 .22038 Mdot
.95455 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00IP3oool3000004d0oooo0`00001W0?ooo`00I@3oool5000004/0oooo1@00001V0?ooo`00
I03oool7000004T0oooo1`00001U0?ooo`00I03ooomG000006D0oooo001T0?ooo`P00000B03oool7
000006D0oooo001U0?ooo`H0000000@0oooo0000000000000000A@3oool7000006D0oooo001V0?oo
o`<000000P3oool010000000oooo0?ooo`3oool300000440oooo00<000000?ooo`00000010000000
0`3oool000000?ooo`1S0?ooo`00IP3oool3000000<0oooo00<000000?ooo`3oool00`3oool30000
03d0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000001S0?ooo`00
I@3oool01@000000oooo0000003oool0000000<0oooo0P0000060?ooo`<00000>03oool200000080
oooo0P0000030?ooo`8000000P3oool200000640oooo001U0?ooo`050000003oool000000?ooo`00
00001@3oool00`000000oooo0?ooo`060?ooo`800000=@3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo05h0oooo001U0?oo
o`050000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`070?ooo`<00000<@3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`000000G`3oool006@0oooo00H000000?ooo`3oool000000?ooo`0000070?oo
o`8000002P3oool3000002`0oooo0P0000030?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000030?ooo`800000G@3oool006@0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo0`00000X0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo05X0oooo001T0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0<0?ooo`<00000903oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool0F@3oool006@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`08
0?ooo`8000003`3oool3000001l0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P00001I
0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0?0?ooo`<000006`3oool00`000000oooo0?ooo`050?ooo`050000003oool0
oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0
EP3oool006<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool04@3oool3000001L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo05D0oooo001S0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo0`00000C0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000005D0oooo001R0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`8000005P3o
ool3000000h0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0DP3o
ool00680oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool05P3oool3000000X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0540oooo001R0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
01P0oooo0`0000060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool20000
0540oooo001Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0>0?ooo`8000006`3oool3000000030?ooo`000000000000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`1>0?ooo`00H@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0K0?ooo`800000
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04d0oooo001Q0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool00`0000060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo0P00
001=0?ooo`00H03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool04P3oool2000001L0oooo0P0000060?ooo`<000000P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo04X0oooo001P0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool02@3oool3000000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0B@3oool00600oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000800000103oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool2000004T0
oooo001O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0E0?ooo`8000003`3oool2000000d0oooo00<000000?ooo`3oool00`3oool3000000030?oo
o`000000oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo04H0oooo001O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`060?ooo`<000003@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0A@3oool005l0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`00000:
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`14
0?ooo`00G`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`<000001`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00d0oooo0P0000140?ooo`00GP3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool2000000D0oooo0P00000@0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool3000000D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo001N0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`050000
003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0
oooo0`0000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`100?ooo`00GP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0000000A0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool03@3oool3000000/0oooo00<000000?ooo`3oool03`3oool200000400oooo
001M0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0J0?ooo`<00000403oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo0P00
00090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0?@3oool005d0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo00D00000
0?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo00000002000000L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0l0?ooo`00G@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo0`000005
0?ooo`030000003oool0oooo0140oooo0P00000l0?ooo`00G03oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool05P3oool2000000L0oooo0P00000:0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?oo
o`<000000`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03T0oooo001L0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool01`3oool4000001D0oooo00<000000?ooo`3o
ool0>03oool005`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`<00000
503oool2000003P0oooo001K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0A0?ooo`8000003`3oool2000000@0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo1000000C0?ooo`030000003o
ool0oooo03D0oooo001K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02`3oool010000000oooo0?oo
o`3oool300000140oooo00<000000?ooo`3oool0=03oool005/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0000000>0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`030?ooo`<000003`3oool2000003@0oooo001J0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01@3oool3000000h0oooo00<000000?ooo`3oool0<@3oool0
05X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo0P00000G0?ooo`040000003oool00000000000`0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0
oooo0300oooo001J0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:
0?ooo`<000002P3oool200000300oooo001I0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`<000002@3oool00`000000oooo0?ooo`0]0?oo
o`00F@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01@3oool2000001T0oooo00<000000?ooo`3oool01@3oool2000000L0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo0P0000080?ooo`03
0000003oool0oooo02`0oooo001I0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0@0?ooo`<000001P3oool2000002`0oooo001I0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`<000001@3o
ool00`000000oooo0?ooo`0Y0?ooo`00903oool300000340oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0?ooo`8000006`3oool00`000000oooo0?oo
o`0;0?ooo`8000000`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0503oool3000000<0oooo00<000000?ooo`0000000P00000V0?ooo`008`3oool5
00000300oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
000001d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000M0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool05`3oool3000000030?ooo`000000000000<000009@3oool0
0280oooo1`00000_0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool20000
01d0oooo00<000000?ooo`3oool03`3oool2000001d0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0I0?ooo`L00000903oool00280oooofP00000T0?ooo`008P3oool7000002h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000001`0
oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0603oool7000002@0oooo000S0?ooo`D00000;`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000K0?oo
o`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000000K0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0603oool5000002D0oooo000T0?ooo`@00000;P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0603oool30000
02H0oooo000T0?ooo`8000000P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo0P00000I0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool05`3oool00`000000oooo0000000W0?ooo`008`3oool00`000000oooo
000000020?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01H0oooo0P00000X0?ooo`008`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`000000:03oool002<0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00P3oool2000000/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00T0oooo0P00000F0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04`3oool010000000oooo0?ooo`00000X0?ooo`008`3oool00`000000oooo00000005
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3o
ool0000000d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0140oooo00@000000?ooo`3oool00000:@3oool00280oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
00003P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0403oool010000000oooo0?ooo`00000Y0?ooo`008P3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0403oool3000000l0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo0P00000C0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0
000002T0oooo000R0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0W0?ooo`008@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0?0?ooo`8000004P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3o
ool0000002X0oooo000Q0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00h0oooo0P0000000`3oool000000?ooo`0A0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`800000403o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0X0?ooo`008@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000
4`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo000P0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0:@3oool00200oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0Y0?ooo`00803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`8000001P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0I0?ooo`800000303oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?ooo`00803oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02X0oooo000O0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0:P3oool001l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01`3oool2000000X0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool07P3oool2000000T0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool0:P3oool001l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0:`3o
ool001h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`8000001`3oool0
0`000000oooo0?ooo`0[0?ooo`007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`8000003P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0R0?ooo`8000001P3oool00`000000oooo0?ooo`0H0?ooo`8000001`3oool00`00
0000oooo0?ooo`0[0?ooo`007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0/0?ooo`007@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`0/0?ooo`007@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool05@3oool010000000oooo0?ooo`3oool200000180oooo00<000000?ooo`3o
ool0503oool01@000000oooo0?ooo`3oool0000001d0oooo00<000000?ooo`3oool09`3oool20000
00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0;03oool001d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000503oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0000001d0oooo00<000000?ooo`3oool0:P3oool01000
0000oooo0?ooo`00000F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0/0?ooo`007@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`0000007@3oool00`000000oooo0?ooo`0[0?ooo`040000003oool0
oooo000001D0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000_0?ooo`00703o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0000000F0?ooo`030000003oool0oooo01D0oooo0P00000N0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`060?ooo`030000003o
ool0000002l0oooo000L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0A0?ooo`8000005`3oool00`000000oooo0?ooo`0E0?ooo`8000007@3oool0
0`000000oooo0?ooo`0^0?ooo`8000004`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
000002l0oooo000L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0?0?ooo`800000603oool00`000000oooo0?ooo`0E0?ooo`8000007@3oool00`00
0000oooo0?ooo`0_0?ooo`8000004@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02h0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0>0?ooo`8000006@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0000001d0
oooo00<000000?ooo`3oool0<03oool200000100oooo00<000000?ooo`3oool02@3oool2000002l0
oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0;0?ooo`80000000<0oooo0000003oool0603oool00`000000oooo0?ooo`0C0?ooo`050000
003oool0oooo0?ooo`0000006`3oool00`000000oooo0?ooo`0a0?ooo`040000003oool000000000
00d0oooo00<000000?ooo`3oool02P3oool2000002l0oooo000K0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?oo
o`0000006@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000006`3oool0
0`000000oooo0?ooo`0a0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?oo
o`0:0?ooo`040000003oool0oooo000002h0oooo000J0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000
6P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0b0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000;@3oool001X0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`020?ooo`80
00001`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0:P3oool001X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`006P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02T0oooo000I0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0603oool010000000oooo0000000000070?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`050?ooo`80000000<0
oooo0000003oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02P0oooo000I
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0X
0?ooo`006@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`0000001`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0000000=0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool09`3oool001P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0G0?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo02H0oooo000H0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool05@3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`8000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02H0oooo000H0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool09@3oool001L0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0T0?ooo`005`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0140oooo0P00000:0?ooo`050000003oool0oooo0?ooo`0000007@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0i0?ooo`050000003oool0oooo0?ooo`0000002P3oool2000000D0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0T0?ooo`005`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00000M0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo03T0oooo00@000000?ooo`3oool000003@3oool01@000000oooo0?ooo`3oool0
000000l0oooo00<000000?ooo`3oool08`3oool001L0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000007P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool00000403oool0
0`000000oooo0?ooo`0R0?ooo`005P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00d0oooo0P00000@0?ooo`8000007P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0j0?ooo`800000403oool30000
0140oooo00<000000?ooo`3oool08@3oool001H0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0100oooo0P00000A0?ooo`030000003oool0oooo0240
oooo000F0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0A0?ooo`8000007P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0k0?ooo`8000004@3oool00`000000oooo
0000000A0?ooo`030000003oool0oooo0200oooo000E0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02@3oool2000001@0oooo00<000000?ooo`0000007@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool000000140oooo00<000000?ooo`3oool00P00000@0?ooo`030000003o
ool0oooo01l0oooo000E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000001`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>P3o
ool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0O0?ooo`005@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01h0oooo000D0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool07@3oool0
01@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`800000603oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool20000
00d0oooo00<000000?ooo`3oool07@3oool001@0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0L0?ooo`00503oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01/0oooo
000C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P00000K0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0000001d0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`8000002`3oool00`000000oooo
0?ooo`0K0?ooo`004`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000001`0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`000000
7@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0J0?ooo`004`3oool00`000000oooo0?ooo`0?0?ooo`8000007@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool00000
7P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0I0?ooo`004P3oool00`000000oooo0?ooo`0?0?ooo`8000007P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000007`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo0P00000:0?ooo`030000003o
ool0oooo01P0oooo000B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000007@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo0P00000Q0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01P0oooo000B0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000007@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo0P00000Q0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01L0oooo000A0?ooo`030000003oool0oooo00`0oooo0P0000030?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`800000203oool00`00
0000oooo0?ooo`0F0?ooo`004@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100
oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo000A0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03`3oool2000002<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00140oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000002<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0503oool00100oooo00<000000?ooo`3oool0203oool2000000P0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00@00000
0?ooo`3oool00000903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo0P00
00050?ooo`030000003oool0oooo01@0oooo000@0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02`3oool010000000oooo0?ooo`00000T0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo000@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3o
ool0000002@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool01@3oool2
000000`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?ooo`050000003oool0
oooo0?ooo`000000=@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool08@3oool2000000<0oooo00<000000?ooo`3oool04P3oool000l0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool08`3oool01@000000oooo0?ooo`3oool0000003@0oooo00<000000?ooo`3oool05@3o
ool01@000000oooo0?ooo`3oool0000002D0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`00
3`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`000000=03oool00`000000
oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000009P3oool01@000000oooo0?ooo`3oool0
00000180oooo000>0?ooo`030000003oool0oooo0080oooo0P00000@0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool08`3oool01@000000oooo0?ooo`3oool0000003<0oooo00<00000
0?ooo`3oool05P3oool010000000oooo0?ooo`00000X0?ooo`8000000P3oool00`000000oooo0?oo
o`0?0?ooo`003P3oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0000003<0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0000000Z0?ooo`030000003oool000000140oooo000;0?ooo`@000000P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0903oool00`000000oooo0000
000b0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`000000:`3oool00`000000oooo0000
0003000000d0oooo000:0?ooo`L00000503oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01T0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool000000380oooo00<000000?ooo`3oool06@3oool2000002d0oooo1P00000<0?ooo`002@3oool7
000001D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0K0?ooo`8000002@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0[0?ooo`L000002`3oool000T0oooo1`00000E0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
02/0oooo1`00000;0?ooo`002@3oool7000001D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0K0?ooo`8000002@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0[0?ooo`L000002`3oool000X0oooo
1@00000F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool06P3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo02@0oooo00<000000?ooo`000000;`3oool00`000000
oooo0?ooo`0L0?ooo`800000;@3oool6000000`0oooo000;0?ooo`D000005@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`000000;P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0000002/0oooo00<000000?ooo`0000000`00000=0?ooo`003P3oool00`000000oooo
0000000D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903oool00`000000oooo
0000000^0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`000000:P3oool01@000000oooo
0000003oool0000000l0oooo000>0?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`000000;03oool00`000000
oooo0?ooo`0M0?ooo`040000003oool0oooo000002P0oooo0P0000020?ooo`800000403oool000l0
oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0
oooo00D000000?ooo`3oool0oooo0000000[0?ooo`030000003oool0oooo01h0oooo00D000000?oo
o`3oool0oooo0000000V0?ooo`070000003oool0oooo0?ooo`000000oooo0000000@0?ooo`003`3o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
8`3oool01@000000oooo0?ooo`3oool0000002/0oooo00<000000?ooo`3oool07P3oool01@000000
oooo0?ooo`3oool0000002D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00h0oooo000?0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000000Z0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`8000000`3o
ool01@000000oooo0?ooo`3oool000000100oooo000@0?ooo`040000003oool0oooo00000140oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo
00D000000?ooo`3oool0oooo0000000T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000140oooo000@0?ooo`05
0000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00000T0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`0000004@3oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000002@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0L0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo000A
0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000S0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0?0?ooo`8000008`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo000A
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0403oool2000002<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01D0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool04@3oool00180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`80
00008@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo000B0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool200000240oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`0000007`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0100oooo0P00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3o
ool001<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?ooo`040000003oool0
oooo000001h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`004`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo0000
000M0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool001<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000007@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo0P00000;0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool04P3oool001@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo000D0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool2000000d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool001D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo000E
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D
0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool00P00000@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool001H0
oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool000000140oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`000000oooo0?ooo`090?ooo`04
0000003oool0oooo000000l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0@0?oo
o`8000004@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo000F0?ooo`03
0000003oool0oooo00T0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00l0oooo0`00000A0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool05@3oool001L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000>0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000@0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool001L0oooo00<000000?ooo`3o
ool02P3oool2000000h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0>0?ooo`05
0000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01H0oooo000G0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo0P0000050?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?ooo`005`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01L0oooo000H0?ooo`030000003oool0oooo00X0oooo0P00
000<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0G0?ooo`00603oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000/0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`8000002@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05`3oool001P0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0G0?ooo`006@3oool00`000000oooo0?ooo`090?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01P0oooo000I0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3o
ool0oooo000000080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0H0?ooo`006@3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?oo
o`0000001`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00D0oooo0P00000@0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?oo
o`006P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool06@3oool001X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00P3o
ool2000001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01T0oooo000J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02d0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`050000
003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000303oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000000K0?oo
o`050000003oool0oooo0?ooo`000000;`3oool01@000000oooo0?ooo`3oool0000001P0oooo00@0
00000?ooo`3oool000004@3oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo0P00000<0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000001/0oooo00D000000?ooo`3oool0
oooo0000000_0?ooo`040000003oool00000000001X0oooo0P00000B0?ooo`030000003oool0oooo
01X0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool2000000/0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0000001d0
oooo00<000000?ooo`000000<03oool2000001`0oooo0P00000B0?ooo`030000003oool0oooo01X0
oooo000L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool05@3oool2000001d0oooo
0P00000`0?ooo`8000007@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01/0oooo
000L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00090?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool05@3oool2000001d0oooo0P00
000_0?ooo`8000007@3oool00`000000oooo0000000A0?ooo`030000003oool0oooo01/0oooo000L
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo00000008
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool05@3oool2000001d0oooo0P00000^
0?ooo`030000003oool0000001d0oooo00<000000?ooo`0000004@3oool00`000000oooo0?ooo`0K
0?ooo`007@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`0000006`3oool00`000000oooo0000000]0?ooo`040000003oool0oooo000001`0oooo00@0
00000?ooo`3oool00000403oool00`000000oooo0?ooo`0L0?ooo`007@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0000
000K0?ooo`030000003oool0000002`0oooo00@000000?ooo`3oool00000703oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0703oool001d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01@0oooo00D0
00000?ooo`3oool0oooo0000000I0?ooo`050000003oool0oooo0?ooo`000000:@3oool2000000<0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0703oool001d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000<03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0M0?ooo`007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0000000`0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo
000N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`800000<@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo0P00
00060?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01d0oooo000N0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`800000<@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0M
0?ooo`007`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0000000`0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo000O0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`000000;`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01h0oooo0P0000090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo000O0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?ooo`00803oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool00200oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool06@3oool2000000`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07`3oool00200oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo000P0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0P0?oo
o`008@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool00240
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool04P3oool200000100oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool00240oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0200oooo000R0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08@3o
ool00280oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000100oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo
00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo00d0oooo0P00000C0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0240oooo000R0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000004P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0000000D0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0Q0?ooo`008`3oool00`000000oooo000000020?ooo`04
0000003oool0oooo000001<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool002<0oooo00D000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`090?ooo`8000005P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01H0oooo00D000000?ooo`3oool0oooo0000000T0?ooo`008`3oool01`000000oooo0000003oool0
00000?ooo`0000005P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0000000E0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00D0
00000?ooo`3oool0oooo0000000T0?ooo`008`3oool010000000oooo0000003oool2000001P0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo
00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3o
ool000009@3oool002@0oooo0`0000000`3oool000000?ooo`0H0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?oo
o`000000503oool00`000000oooo0?ooo`040?ooo`8000006@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`0000009@3oool002@0oooo1000000J0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?ooo`@0
00009@3oool002<0oooo1@00000K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4@3oool01@000000oooo0?ooo`3oool0000001/0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0H0?ooo`D000009@3oool00280oooo1`00000K0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0603oool7000002@0oooo000R0?ooomX00000903oool00280oooo2000
000K0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool2000001d0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0I0?ooo`L00000903oool002<0oooo1P000000
103oool0000000000000000I0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0000000M0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3o
ool3000000030?ooo`000000000000<000009@3oool002@0oooo0`0000020?ooo`040000003oool0
oooo0?ooo`<000005P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo0P00
00030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0D0?ooo`<000001@3oool3000002H0oooo000Z0?ooo`030000003oool0oooo00<0oooo0`00000D
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B
0?ooo`<00000<@3oool002/0oooo0P0000060?ooo`<000004P3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool3000003@0oooo000]0?ooo`03
0000003oool0oooo00H0oooo0P00000A0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool01@3oool2000000L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00l0oooo0P00000g0?ooo`00;P3oool00`000000oooo0?ooo`070?ooo`<00000
3P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool3000003T0oooo000_0?ooo`8000002P3oool3000000`0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00X0oooo0`00000l0?ooo`00<@3oool00`000000oooo0?oo
o`0:0?ooo`<000002P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`040000003oool00000000000`0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo
0`00000o0?ooo`00<P3oool00`000000oooo0?ooo`0<0?ooo`<000001`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00D0oooo0`0000120?ooo`00<`3oool2000000l0oooo0`000005
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool3000004D0oooo000e0?oo
o`030000003oool0oooo00l0oooo0`0000030?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00D000000?oo
o`3oool0oooo0000000=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02`3oool0
10000000oooo0?ooo`3oool3000004P0oooo000f0?ooo`030000003oool0oooo0140oooo1000000I
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0C
0?ooo`800000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool02`3oool4000004/0oooo000g0?ooo`800000503oool3000001L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool02P3oool3000004h0oooo000i0?ooo`030000003oool0oooo01<0oooo1000000D0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00L0oooo1000001@0?ooo`00>P3oool00`000000oooo0?ooo`0B0?ooo`040000
003oool0oooo0?ooo`<000004@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool04@3oool2000000X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo0`0000030?ooo`030000003oool0oooo04h0
oooo000k0?ooo`8000004`3oool00`000000oooo0?ooo`030?ooo`<000003P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`1?0?ooo`00?@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00D0oooo0`00000;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000008000001`3o
ool00`000000oooo0?ooo`1@0?ooo`00?P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00L0oooo0P0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0?0?ooo`800000403oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0140oooo0P0000090?ooo`030000003oool0oooo0540oooo000o0?ooo`8000004@3oool00`00
0000oooo0?ooo`090?ooo`<000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03@3oool3000000/0oooo00<000000?ooo`3oool0D@3oool00440
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`<000000`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool300000080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1B0?ooo`00@P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00d0oooo100000080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool2000001L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`<000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05<0oooo
00130?ooo`8000003`3oool00`000000oooo0?ooo`0@0?ooo`<000001@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00<0oooo0`0000070?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0D`3oool004D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00<000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<000002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05@0oooo00160?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?oo
o`<00000203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01P3oool3000000d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1E0?oo
o`00A`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0103oool00`000000oooo00000002000000D0oooo00<000000?ooo`3oool02`3oool2000001h0
oooo00<000000?ooo`3oool00`3oool3000000030?ooo`000000oooo00d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1E0?ooo`00B03oool2000000d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0`0000000`3oool00000
0?ooo`0<0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`0000000P0000040?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1F0?ooo`00BP3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`<000002`3oool00`000000oooo0?ooo`0O0?ooo`<000001`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E`3o
ool004/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`03000000H0oooo0P00000O
0?ooo`<000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1G0?ooo`00C03oool2000000/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool300000080oooo00<000000?ooo`3oool0703oool3000000H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0F03oool004h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`80
00007@3oool2000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0F@3oool004l0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`070?ooo`80000000@0oooo00000000000000005`3oool3000000`0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0FP3oool00500oooo0P0000090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0103oool300000140oooo0`00000@0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05X0oooo
001B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`<000002`3oool3000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0F`3oool005<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`8000003P3oool3000000D0oooo0`00000H
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo05`0oooo001D0?ooo`8000001`3oool00`000000oooo0?ooo`070?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0140oooo1@00000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo05`0oooo001F0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`<0000000@0oooo00000000000000006`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1M0?ooo`00E`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03`3oool3000000L0oooo0`00000I0?ooo`050000003oool0oooo0?ooo`000000
1`3oool01@000000oooo0?ooo`3oool000000600oooo001H0?ooo`8000001@3oool00`000000oooo
0?ooo`050?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool2000000l0
oooo0`00000=0?ooo`<000005P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1N0?ooo`00FP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo0`00000C0?ooo`<00000503oool01@000000
oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo0000001Q0?ooo`00F`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo0`00000I0?ooo`<000004P3oool0
10000000oooo0?ooo`0000050?ooo`040000003oool0oooo00000680oooo001L0?ooo`8000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool0oooo
0P00000:0?ooo`<000007`3oool3000000l0oooo00D000000?ooo`3oool0oooo000000040?ooo`04
0000003oool0oooo00000680oooo001N0?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000002@3oool3000002D0oooo0`00000=
0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000H`3oool005l0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`060?ooo`800000:`3oool2000000`0oooo00<000000?ooo`0000000`3oool00`000000
oooo0000001T0?ooo`00H03oool200000080oooo00D000000?ooo`3oool000000?ooo`0200000080
oooo0P0000060?ooo`<00000;`3oool3000000X0oooo0P0000030?ooo`800000I@3oool00680oooo
00<000000?ooo`0000000P3oool2000000040?ooo`000000oooo000000D0oooo0`00000e0?ooo`<0
00001`3oool01`000000oooo0000003oool000000?ooo`000000I@3oool006<0oooo00<000000?oo
o`000000100000000`3oool000000?ooo`020?ooo`<00000>`3oool3000000D0oooo1@00001V0?oo
o`00I03oool7000000040?ooo`000000000000000440oooo0`0000020?ooo`D00000IP3oool006@0
oooo200000170?ooo`P00000I@3oool006@0oooo1`0000190?ooo`L00000I@3oool006@0oooo1`00
00190?ooo`L00000I@3oool006D0oooo1@00001;0?ooo`D00000IP3oool006H0oooo0`00001=0?oo
o`<00000I`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500054, -0.0255335, \
0.00383279, 0.00366225}}]
}, Open  ]],

Cell["\<\
Die zugeh\[ODoubleDot]rige Adjacency-Matrix erh\[ADoubleDot]lt man \
auf folgende Weise:\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m1 = ToAdjacencyMatrix[g1];\)\), "\[IndentingNewLine]", 
    \(m1 // MatrixForm\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "1", "1", "0", "0", "0", "1", "0", "1"},
            {"0", "0", "0", "1", "0", "1", "1", "0", "1", "1"},
            {"1", "0", "0", "1", "1", "0", "1", "1", "1", "1"},
            {"1", "1", "1", "0", "1", "1", "1", "1", "0", "0"},
            {"0", "0", "1", "1", "0", "1", "0", "1", "0", "0"},
            {"0", "1", "0", "1", "1", "0", "0", "0", "1", "0"},
            {"0", "1", "1", "1", "0", "0", "0", "1", "1", "1"},
            {"1", "0", "1", "1", "1", "0", "1", "0", "1", "1"},
            {"0", "1", "1", "0", "0", "1", "1", "1", "0", "0"},
            {"1", "1", "1", "0", "0", "0", "1", "1", "0", "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Man sieht unmittelbar, dass es sich um eine symmetrische Matrix handelt. \
Eine einfache (aber informatisch nicht ganz trivial zu ermittelnde) Abfrage \
ist in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " vorinstalliert: der Zusammenhang eines Graphen. Der Befehl ",
  StyleBox["ConnectedQ[g1]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " gibt die Werte ",
  StyleBox["True",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " oder ",
  StyleBox["False",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " aus, je nachdem, ob der Graph ",
  StyleBox["g1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " zusammenh\[ADoubleDot]ngend oder nicht-zusammenh\[ADoubleDot]ngend ist."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConnectedQ[g1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Mit Hilfe dieses Befehls l\[ADoubleDot]sst sich das bereits in diesem \
Kapitel diskutierte Perkolationsph\[ADoubleDot]nomen bei ER-Graphen \
untersuchen. Dazu erzeugt man einen Zufallsgraphen mit vorgegebenem \
Vernetzungsgrad und fragt den Zusammenhang ab. Zwei ",
  StyleBox["Do",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleifen stellen eine entsprechende Zahl von Wiederholungen und die \
Variation des Vernetzungsgrades bereit. Zum Schluss z\[ADoubleDot]hlt man \
nach, wie h\[ADoubleDot]ufig in den Wiederholungen zu jedem Vernetzungsgrad \
der Wert ",
  StyleBox["True",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " aufgetreten ist."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[{Print["\<Vernetzungsgrad=\>", 
          pp], \[IndentingNewLine]Do[{gX = 
              RandomGraph[200, pp], \(cc[ii] = ConnectedQ[gX];\)}, {ii, 1, 
            20}], \[IndentingNewLine]ccFull = 
          Table[cc[ii], {ii, 1, 100}]; \[IndentingNewLine]cc2[pp] = 
          Count[ccFull, True]}, {pp, 0.0, 0.1, 0.01}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Vernetzungsgrad="\[InvisibleSpace]0.`\),
      SequenceForm[ "Vernetzungsgrad=", 0.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Vernetzungsgrad="\[InvisibleSpace]0.01`\),
      SequenceForm[ "Vernetzungsgrad=", .01],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Vernetzungsgrad="\[InvisibleSpace]0.02`\),
      SequenceForm[ "Vernetzungsgrad=", .02],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Vernetzungsgrad="\[InvisibleSpace]0.03`\),
      SequenceForm[ "Vernetzungsgrad=", .029999999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Vernetzungsgrad="\[InvisibleSpace]0.04`\),
      SequenceForm[ "Vernetzungsgrad=", .040000000000000001],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Vernetzungsgrad="\[InvisibleSpace]0.05`\),
      SequenceForm[ "Vernetzungsgrad=", .050000000000000003],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Vernetzungsgrad="\[InvisibleSpace]0.06`\),
      SequenceForm[ "Vernetzungsgrad=", .059999999999999998],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Vernetzungsgrad="\[InvisibleSpace]0.07`\),
      SequenceForm[ "Vernetzungsgrad=", .070000000000000007],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Vernetzungsgrad="\[InvisibleSpace]0.08`\),
      SequenceForm[ "Vernetzungsgrad=", .080000000000000002],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Vernetzungsgrad="\[InvisibleSpace]0.09`\),
      SequenceForm[ "Vernetzungsgrad=", .089999999999999997],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Vernetzungsgrad="\[InvisibleSpace]0.1`\),
      SequenceForm[ "Vernetzungsgrad=", .10000000000000001],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  "Eine Auftragung dieser Gr\[ODoubleDot]\[SZ]e ",
  StyleBox["cc2",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " als Funktion des Vernetzungsgrades f\[UDoubleDot]hrt auf den oberen Teil \
von Abb. 5.28. Kehren wir zur\[UDoubleDot]ck zu den Small-World-Graphen. Den \
regul\[ADoubleDot]ren Backbone entwerfen wir durch eine schrittweise \
Konstruktion der Adjacency-Matrix. Dazu initialisieren wir die Matrix mit \
Nullen als Eintr\[ADoubleDot]ge und f\[UDoubleDot]gen nun jeweils in der ",
  StyleBox["i",
    FontSlant->"Italic"],
  "-ten Zeile ",
  StyleBox["m",
    FontSlant->"Italic"],
  " Einsen an den Stellen ",
  StyleBox["i",
    FontSlant->"Italic"],
  " + 1, ",
  StyleBox["i",
    FontSlant->"Italic"],
  " + 2, . . . , ",
  StyleBox["i",
    FontSlant->"Italic"],
  " + ",
  StyleBox["m",
    FontSlant->"Italic"],
  " ein. Dabei sind zwei kleinere Besonderheiten zu beachten: (1) Zusammen \
mit einer Eins an der Stelle (",
  StyleBox["i, j",
    FontSlant->"Italic"],
  "), die nach diesem Schema eingef\[UDoubleDot]gt wird, muss auch eine Eins \
an die Stelle (",
  StyleBox[" j, i",
    FontSlant->"Italic"],
  ") eingef\[UDoubleDot]gt werden, um die Symmetrie der Matrix zu gew\
\[ADoubleDot]hrleisten. (2) Um zu verhindern, dass die Knotennummern ",
  StyleBox["i + k",
    FontSlant->"Italic"],
  ", die in diesem Schema verwendet werden, die Zahl ",
  StyleBox["N",
    FontSlant->"Italic"],
  " der Knoten \[UDoubleDot]bersteigt, tr\[ADoubleDot]gt man diese \
Koordinaten ",
  StyleBox["modulo N",
    FontSlant->"Italic"],
  " ein. Der Befehl ",
  StyleBox["Mod[a,N]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " liefert den Rest von ",
  StyleBox["a",
    FontSlant->"Italic"],
  " nach Abzug ganzzahliger Vielfacher von ",
  StyleBox["N",
    FontSlant->"Italic"],
  ". Dies ist ein sehr n\[UDoubleDot]tzlicher Befehl, um eine ganze Zahl auf \
eine geschlossene Kette abzubilden."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Mod[j - 1, 5] + 1, {j, 1, 15}]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 1, 2, 3, 4, 5, 1, 2, 3, 4, 5}\)], "Output"]
}, Open  ]],

Cell["\<\
Man beachte die Indexverschiebung, die sicherstellt, dass die \
resultierenden Werte zwischen (in diesem Fall) 1 und 5 liegen (und nicht \
zwischen 0 und 4). Insgesamt ergibt sich also die folgende Routine zur \
Erzeugung von regul\[ADoubleDot]ren Backbone-Graphen:\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(backbone[nn_, neigh_] := 
      Module[{mm1}, \[IndentingNewLine]mm1 = 
          Table[0, {ii, 1, nn}, {jj, 1, nn}]; \[IndentingNewLine]Do[
          Do[{mm1[\([ii, Mod[ii + kk - 1, nn] + 1]\)] = 1, 
              mm1[\([Mod[ii + kk - 1, nn] + 1, ii]\)] = 1}, {ii, 1, 
              nn}], {kk, 1, neigh}]; \[IndentingNewLine]mm1]\)], "Input"],

Cell["\<\
Das Ergebnis ist eine Adjacency-Matrix, die sich mit einem \
entsprechenden Befehl in einen Graphen \[UDoubleDot]bersetzen \
l\[ADoubleDot]sst.\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g3 = 
        FromAdjacencyMatrix[backbone[10, 3]];\)\), "\[IndentingNewLine]", 
    \(\(ShowGraph[g3];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.909091 0.0242882 0.951424 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.005 w
[ ] 0 setdash
.86773 .77962 m
.64046 .95243 L
s
.86773 .77962 m
.35954 .95243 L
s
.86773 .77962 m
.13227 .77962 L
s
.86773 .77962 m
.64046 .04757 L
s
.86773 .77962 m
.86773 .22038 L
s
.86773 .77962 m
.95455 .5 L
s
.64046 .95243 m
.35954 .95243 L
s
.64046 .95243 m
.13227 .77962 L
s
.64046 .95243 m
.04545 .5 L
s
.64046 .95243 m
.86773 .22038 L
s
.64046 .95243 m
.95455 .5 L
s
.35954 .95243 m
.13227 .77962 L
s
.35954 .95243 m
.04545 .5 L
s
.35954 .95243 m
.13227 .22038 L
s
.35954 .95243 m
.95455 .5 L
s
.13227 .77962 m
.04545 .5 L
s
.13227 .77962 m
.13227 .22038 L
s
.13227 .77962 m
.35954 .04757 L
s
.04545 .5 m
.13227 .22038 L
s
.04545 .5 m
.35954 .04757 L
s
.04545 .5 m
.64046 .04757 L
s
.13227 .22038 m
.35954 .04757 L
s
.13227 .22038 m
.64046 .04757 L
s
.13227 .22038 m
.86773 .22038 L
s
.35954 .04757 m
.64046 .04757 L
s
.35954 .04757 m
.86773 .22038 L
s
.35954 .04757 m
.95455 .5 L
s
.64046 .04757 m
.86773 .22038 L
s
.64046 .04757 m
.95455 .5 L
s
.86773 .22038 m
.95455 .5 L
s
.025 w
.86773 .77962 Mdot
.64046 .95243 Mdot
.35954 .95243 Mdot
.13227 .77962 Mdot
.04545 .5 Mdot
.13227 .22038 Mdot
.35954 .04757 Mdot
.64046 .04757 Mdot
.86773 .22038 Mdot
.95455 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00IP3oool3000004d0oooo0`00001W0?ooo`00I@3oool5000004/0oooo1@00001V0?ooo`00
I03oool7000004T0oooo1`00001U0?ooo`00I03ooomG000006D0oooo001T0?ooo`P00000A`3oool8
000006D0oooo001T0?ooo`L0000000@0oooo0000000000000000@@3oool3000000030?ooo`000000
000000D00000I@3oool006<0oooo00<000000?ooo`0000000`0000020?ooo`040000003oool0oooo
0?ooo`<00000>`3oool3000000<0oooo00<000000?ooo`3oool0100000000`3oool000000?ooo`1S
0?ooo`00HP3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00`3oool3
000003D0oooo0`0000050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000
001S0?ooo`00H03oool200000080oooo0P0000070?ooo`8000001P3oool3000002l0oooo0`000006
0?ooo`8000001`3oool200000080oooo0P00001Q0?ooo`00G`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000002@3oool00`000000oooo0?ooo`060?ooo`800000:`3oool2000000P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo000000030?ooo`030000003oool0oooo05h0oooo001N
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo0`00000U0?ooo`<000002@3oool00`000000oooo0?ooo`080?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0G@3oool005`0oooo0P0000030?ooo`040000003o
ool0oooo000000`0oooo0P00000:0?ooo`<000007`3oool3000000X0oooo0P00000<0?ooo`040000
003oool0oooo000000<0oooo0P00001M0?ooo`00F`3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000h0oooo00<000000?ooo`3oool02P3oool3000001T0oooo0`00000<0?ooo`03
0000003oool0oooo00`0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1J0?oo
o`00FP3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000003`3oool00`00
0000oooo0?ooo`0<0?ooo`<000004`3oool3000000h0oooo00<000000?ooo`3oool03@3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0F@3oool005P0oooo0P0000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool2000000l0oooo0`00000=0?oo
o`<000003`3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`800000F@3oool005L0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
01<0oooo00<000000?ooo`3oool03`3oool3000000L0oooo0`00000A0?ooo`030000003oool0oooo
0140oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo05H0oooo001F0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0140oooo0`000000103oool0000000000000000C0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo05D0oooo001D0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04@3oool5000001<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P00001E0?ooo`00D`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool2000000h0
oooo0`0000050?ooo`<000003P3oool2000001L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo
0`00000;0?ooo`<000002P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1A0?ooo`00D03oool2000000T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo0`00
000A0?ooo`<000001P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01`3oool200000540oooo001?0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`80000000@0oooo00000000000000005`3o
ool3000000030?ooo`000000000001`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo04h0oooo001>0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`8000007@3oool2000001d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04d0oooo001<0?oo
o`8000002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo0`0000020?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`00000J0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02@3oool2000004d0oooo001;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`<000001P3oool2000001L0
oooo0P0000060?ooo`<00000603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0BP3oool004X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01<0oooo0`00000;0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool02@3oool3000001D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo04T0oooo00180?ooo`8000003@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0100oooo0`00000?0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool03@3oool300000180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0;0?ooo`800000B@3oool004L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00h0oooo0`00000C0?ooo`8000003`3oool2000001<0oooo0`00000@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`16
0?ooo`00AP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02`3oool3000001P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?oo
o`<000003@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0A@3oool004D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo0`00000L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool06P3oool3000000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo04@0oooo00130?ooo`8000003`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00D0oooo0`00000P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
7P3oool3000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`800000
A03oool00480oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo0`00000T0?ooo`8000001@3oool2000002@0oooo0`0000050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`110?ooo`00@@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`00000Y
0?ooo`050000003oool0oooo0?ooo`000000:@3oool300000080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0400oooo000o0?ooo`8000004@3oool0
0`000000oooo0?ooo`090?ooo`<00000;@3oool00`000000oooo0000000]0?ooo`<000002`3oool0
0`000000oooo0?ooo`0?0?ooo`800000@03oool003h0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`070?ooo`800000<03oool300000300oooo0P0000090?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0?@3oool003d0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`050?ooo`<0000000<0oooo0000003oool0;P3oool01@000000oooo0?ooo`3oool00000
02l0oooo00<000000?ooo`0000000P0000070?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0?03oool003/0oooo0P00000C0?ooo`030000003oool0oooo00<0oooo0`0000040?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo0P00000l0?ooo`00
>P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo0?ooo`<000001P3oool00`000000
oooo0?ooo`0[0?ooo`8000001`3oool2000002d0oooo00<000000?ooo`3oool0103oool3000000<0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0i0?ooo`00>@3oool00`000000oooo
0?ooo`0C0?ooo`@000002@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`070?ooo`@000005@3oool00`000000oooo
0?ooo`0h0?ooo`00=`3oool2000001@0oooo0`00000<0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00X0oooo0`00
000D0?ooo`800000>03oool003H0oooo00<000000?ooo`3oool04@3oool4000000d0oooo00<00000
0?ooo`3oool0:03oool2000000l0oooo0P00000Z0?ooo`030000003oool0oooo00/0oooo1000000C
0?ooo`030000003oool0oooo03D0oooo000e0?ooo`030000003oool0oooo00l0oooo0`0000030?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`3oool3
00000140oooo00<000000?ooo`3oool0=03oool003<0oooo0P00000?0?ooo`<000001@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool30000
00l0oooo0P00000d0?ooo`00<P3oool00`000000oooo0?ooo`0<0?ooo`<000001`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool3000000h0
oooo00<000000?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool02P3oool3000000X0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0T0?ooo`8000006@3oool2000002H0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo
0?ooo`0`0?ooo`00;`3oool2000000X0oooo0`00000<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`<000002P3oool200000300oooo000^
0?ooo`030000003oool0oooo00L0oooo0`00000>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`<000002@3oool00`000000oooo0?ooo`0]
0?ooo`00;@3oool00`000000oooo0?ooo`060?ooo`8000004@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0240oooo0P00000Q0?ooo`8000008`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00l0oooo0P0000080?ooo`030000003oool0oooo02`0oooo000[0?ooo`80
00001P3oool300000180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0100oooo0`0000060?ooo`800000;03oool002X0oooo00<000000?ooo`3oool0
0`3oool3000001@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0180oooo0`0000050?ooo`030000003oool0oooo02T0oooo000T0?ooo`<000000P3o
ool010000000oooo0?ooo`3oool3000001H0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0N0?ooo`800000:@3oool200000200oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0D0?ooo`<000000`3oool00`000000oooo00000002000002H0oooo000S0?ooo`H0000000@0
oooo00000000000000006@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool05`3oool3000000030?ooo`000000000000<000009@3oool00280oooo2000
000K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0I0?ooo`L00000903oool00280oooofP00000T0?ooo`008P3oool7000001/0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo1`00000T0?oo
o`008`3oool5000001/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01P0oooo1@00000U0?ooo`00903oool3000001/0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo1000000U0?ooo`00903o
ool3000001/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`800000>`3o
ool2000001T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`<000009@3o
ool002<0oooo00D000000?ooo`000000oooo0000000I0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`040000003oool00000000002D0oooo
000S0?ooo`050000003oool000000?ooo`000000603oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool05P3oool01@000000oooo0000003oool0000002@0
oooo000S0?ooo`050000003oool000000?ooo`000000603oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01@0oooo0P0000130?ooo`8000005P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01H0oooo00D000000?ooo`000000oooo0000000T0?ooo`008`3oool00`000000
oooo000000020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00H000000?ooo`3oool000000?ooo`00000T
0?ooo`008P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0Q0?ooo`008P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0A0?ooo`800000B`3oool2000001<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0B0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool08@3oool00280oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool08@3oool00240oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0200oooo000Q0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool2000005<0oooo0P00000@0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool0803oool00240oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo0200oooo000P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
000R0?ooo`00803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool07`3oool00200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`800000G@3oool2000000`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?oo
o`00803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool07`3oool001l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01h0oooo000O0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01`3o
ool2000006D0oooo0P0000090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3o
ool001l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01h0oooo000N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0M0?ooo`007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0
oooo0P00001]0?ooo`8000001P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0
oooo000N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0M0?ooo`007@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool07@3oool001d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`3o
ool2000007D0oooo0P0000030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0703o
ool001d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`00001i0?ooo`040000003o
ool0oooo000001`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0703oool001d0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000001`0oooo00@000000?ooo`3oool0
0000N`3oool010000000oooo0?ooo`00000L0?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0L0?ooo`00703oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`0000007@3oool00`000000oooo0000001m0?oo
o`030000003oool0000001d0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01/0oooo000L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0000000M0?ooo`800000O`3oool2000001d0oooo00<000000?ooo`00
0000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo000L0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`800000
P@3oool2000001d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01/0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool2000001`0oooo0P0000230?ooo`800000703oool2000000P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo0P00000J0?ooo`80000000<0oooo0000003oool0PP3oool010000000oooo00000000
000J0?ooo`800000203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo000K
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00
000H0?ooo`050000003oool0oooo0?ooo`000000P`3oool01@000000oooo0?ooo`3oool0000001P0
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01X0oooo000J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool0000001L0oooo00D000000?ooo`3oool0oooo000000250?ooo`050000003oool0
oooo0?ooo`0000005`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0J0?ooo`006P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`800000103o
ool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0080oooo0P00000E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01T0oooo000J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool02@3oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool03P3oool2000000L0oooo00<000000?oo
o`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`800000403oool00`000000oooo0?ooo`050?oo
o`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`0H0?ooo`006@3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000/0oooo00<000000?ooo`3oool0603oool001T0oooo00<000000?ooo`3oool02@3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
603oool001P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000000:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`270?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0000000`0oooo00<000000?ooo`3oool05`3oool001P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0000000;0?ooo`030000003oool0oooo00L0oooo0P00000;0?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool02@3oool2000000T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0000000<0?ooo`030000003oool0oooo01L0oooo000H0?ooo`030000003oool0oooo
00X0oooo0P00000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0:0?ooo`800000303oool00`000000oooo0?ooo`0G0?ooo`005`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0G0?ooo`005`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool2000000h0oooo00<000000?ooo`3oool0R@3oool00`000000oooo
0?ooo`0<0?ooo`8000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool05P3oool001L0oooo00<000000?ooo`3oool02P3oool2000000h0oooo00D0
00000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0
3P3oool01@000000oooo0?ooo`3oool0000000h0oooo0P00000<0?ooo`030000003oool0oooo01H0
oooo000G0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000003P3oool010000000oooo
0?ooo`00000@0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool03P3oool010000000
oooo0?ooo`00000>0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool05P3oool001H0
oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000>0?ooo`<000004@3oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo00l0oooo0`00000>0?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool05@3oool001H0oooo00<000000?ooo`3oool02@3oool01000
0000oooo0?ooo`00000>0?ooo`8000004P3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo0100oooo0P00000>0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool05@3o
ool001H0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000d0oooo00<0
00000?ooo`0000004@3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
5@3oool001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00T0oooo0P0000020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo008000002`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool001D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo000E0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?oo
o`00503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0503oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo0P0000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo0P0000060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`00503o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3o
ool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0940oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01<0oooo000C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`02000000h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool200000080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo000C0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000@0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0180oooo000C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool200000140oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool2000000X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0B0?ooo`004P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo0P00000B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo0P00000:0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool0
0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000001<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04@3oool00140oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`8000000`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0140oooo00@000000?ooo`3oool0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04@3oool00140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0100oooo000A0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`004@3oool01@000000oooo0?ooo`3oool00000
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo
0?ooo`0000004P3oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`800000203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool01P3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?oo
o`00403oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0V@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000004@3oool00100oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000004@3oool000l0oooo00D000000?ooo`3oool0oooo000000030?ooo`800000303o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0V@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02P3o
ool2000000<0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`003`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0503oool01@000000oooo
0?ooo`3oool0000009d0oooo00D000000?ooo`3oool0oooo0000000F0?ooo`030000003oool0oooo
00`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00h0oooo000?0?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?oo
o`050000003oool0oooo0?ooo`000000W@3oool01@000000oooo0?ooo`3oool0000001H0oooo00<0
00000?ooo`3oool03@3oool01`000000oooo0?ooo`3oool000000?ooo`000000403oool000h0oooo
00<000000?ooo`0000000P3oool200000100oooo00<000000?ooo`3oool05@3oool010000000oooo
0?ooo`00002M0?ooo`040000003oool0oooo000001L0oooo00<000000?ooo`3oool03P3oool20000
0080oooo0P00000@0?ooo`003P3oool01@000000oooo0000003oool000000180oooo00<000000?oo
o`3oool05@3oool00`000000oooo0000002O0?ooo`030000003oool0000001L0oooo00<000000?oo
o`3oool0403oool01@000000oooo0000003oool0000000l0oooo000;0?ooo`D0000000<0oooo0000
003oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0000009l0oooo00<000000?oo
o`0000005`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0000000<000003@3oool000X0
oooo1`00000D0?ooo`030000003oool0oooo01H0oooo0P00002O0?ooo`800000603oool00`000000
oooo0?ooo`0B0?ooo`H00000303oool000T0oooo1`00000E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo
1`00000;0?ooo`002@3oool7000001D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool7000000/0oooo0009
0?ooo`L000005@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`L000002`3oool000X0oooo1`00000D0?oo
o`030000003oool0oooo01H0oooo0P00002O0?ooo`800000603oool00`000000oooo0?ooo`0B0?oo
o`H00000303oool000/0oooo1@0000000`3oool000000?ooo`0B0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`000000W`3oool00`000000oooo0000000G0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`0000000`00000=0?ooo`003P3oool01@000000oooo0000003oool000000180
oooo00<000000?ooo`3oool05@3oool00`000000oooo0000002O0?ooo`030000003oool0000001L0
oooo00<000000?ooo`3oool0403oool01@000000oooo0000003oool0000000l0oooo000>0?ooo`03
0000003oool000000080oooo0P00000@0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3o
ool00000W@3oool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo00h0oooo0P000002
0?ooo`800000403oool000l0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000002M0?ooo`050000003oool0
oooo0?ooo`0000005P3oool00`000000oooo0?ooo`0=0?ooo`070000003oool0oooo0?ooo`000000
oooo0000000@0?ooo`003`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0000009d0oooo00D000000?oo
o`3oool0oooo0000000F0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00h0oooo000?0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool2000000`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo09T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00X0oooo0P0000030?ooo`050000003oool0oooo0?ooo`000000403oool00100oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000004@3oool00100oooo00D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
0140oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000P0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo09L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0
oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00140oooo
00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool000000180oooo000A0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00140oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`8000000`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000001<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
4@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool04@3oool00180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000
003oool0000001<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2E0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo000000090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`080?ooo`8000004P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`8000002P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo000C0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0203oool200000140oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool2
000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000403oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0B0?ooo`004`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P00000>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0T@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo0P0000020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4`3oool001@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0940oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01<0oooo000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`8000002@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`8000001P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool0
01@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01@0oooo000E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo0P0000020?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo008000002`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503o
ool001H0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000d0oooo00<0
00000?ooo`0000004@3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
5@3oool001H0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000>0?ooo`800000
4P3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0100oooo0P00000>0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool05@3oool001H0oooo00<000000?ooo`3oool0
2@3oool010000000oooo0?ooo`00000>0?ooo`<000004@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo00l0oooo0`00000>0?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool05@3oool001L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000>0?ooo`04
0000003oool0oooo00000100oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0>0?oo
o`040000003oool0oooo000000h0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0F
0?ooo`005`3oool00`000000oooo0?ooo`0:0?ooo`8000003P3oool01@000000oooo0?ooo`3oool0
00000100oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0
oooo0?ooo`0000003P3oool2000000`0oooo00<000000?ooo`3oool05P3oool001L0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo0P00000>
0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0303oool2000000D0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo000G0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01L0oooo000H0?ooo`030000003oool0oooo00X0oooo0P00000<0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`80
0000303oool00`000000oooo0?ooo`0G0?ooo`00603oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0000000/0oooo00<000000?ooo`3oool01`3oool2000000/0oooo00<000000?ooo`3oool0
Q`3oool00`000000oooo0?ooo`090?ooo`8000002@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0000000`0oooo00<000000?ooo`3oool05`3oool001P0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0000000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool05`3o
ool001T0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`270?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`3oool0603oool001T0oooo00<000000?ooo`3oool02@3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`03
0000003oool0oooo01P0oooo000I0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0
oooo000000070?ooo`030000003oool0oooo00h0oooo0P0000070?ooo`030000003oool0oooo08D0
oooo00<000000?ooo`3oool01@3oool200000100oooo00<000000?ooo`3oool01@3oool01@000000
oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0603oool001X0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01T0oooo000J0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`230?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0I0?ooo`006P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0C0?ooo`800000103oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo0080oooo0P00000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01T0oooo000J0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000001L0oooo00D0
00000?ooo`3oool0oooo000000250?ooo`050000003oool0oooo0?ooo`0000005`3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?oo
o`006`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool00000603oool01@000000oooo0?ooo`3oool0000008<0oooo00D000000?ooo`3oool0oooo0000
000H0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0P00
000J0?ooo`80000000<0oooo0000003oool0PP3oool010000000oooo00000000000J0?ooo`800000
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo000K0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool2000001`0oooo0P0000230?ooo`800000703o
ool2000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`00703oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool2
00000840oooo0P00000M0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0K0?ooo`00703oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`0000007@3oool2000007l0oooo0P00000M0?ooo`030000003oool00000
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`00703oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000007@3oool00`000000
oooo0000001m0?ooo`030000003oool0000001d0oooo00<000000?ooo`000000203oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo000M0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000L0?ooo`040000003oool0oooo0000
07/0oooo00@000000?ooo`3oool00000703oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool001d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool0
10000000oooo0?ooo`00001i0?ooo`040000003oool0oooo000001`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
703oool001d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`3oool2000007D0oooo
0P0000030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0703oool001d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo000N
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M
0?ooo`007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo0P00001]0?oo
o`8000001P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo000N0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`00
7`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
7P3oool001l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`800000I@3o
ool2000000T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`007`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool0
0200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
05l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01l0oooo000P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool2000005d0
oooo0P00000<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07`3oool00200oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01l0oooo
000P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000R0?ooo`008@3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0803oool00240oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0>0?ooo`800000D`3oool200000100oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0P0?oo
o`008@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0403oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0803oool00280oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool08@3oool00280oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool2000004/0oooo0P00
000C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0240oooo000R0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0240
oooo000S0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool01P000000oooo
0?ooo`000000oooo000002@0oooo000S0?ooo`050000003oool000000?ooo`000000603oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo0P0000130?ooo`8000005P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00D000000?ooo`000000oooo0000000T
0?ooo`008`3oool01@000000oooo0000003oool0000001P0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00D000000?ooo`000000oooo0000
000T0?ooo`008`3oool01@000000oooo0000003oool0000001T0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`0000000000
9@3oool002@0oooo0`00000K0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3o
ool2000003/0oooo0P00000I0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3o
ool3000002D0oooo000T0?ooo`<000006`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0603oool4000002D0oooo000S0?ooo`D000006`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0603oool50000
02D0oooo000R0?ooo`L000006`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0603oool7000002@0oooo000R0?ooomX00000903oool00280oooo2000
000K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0I0?ooo`L00000903oool002<0oooo1P000000103oool0000000000000000I0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`<0000000<0
oooo0000000000000`00000U0?ooo`00903oool300000080oooo00@000000?ooo`3oool0oooo0`00
000F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool07P3oool2000002T0oooo0P00
000P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool3000000<0oooo00<0
00000?ooo`0000000P00000V0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`<00000503oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool3
000000D0oooo00<000000?ooo`3oool0:@3oool002/0oooo0P0000060?ooo`<000004P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool30000
00H0oooo0P00000/0?ooo`00;@3oool00`000000oooo0?ooo`060?ooo`8000004@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0240oooo0P00000Q0?ooo`8000008`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo0P0000080?ooo`030000003oool0oooo02`0
oooo000^0?ooo`030000003oool0oooo00L0oooo0`00000>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`<000002@3oool00`000000oooo
0?ooo`0]0?ooo`00;`3oool2000000X0oooo0`00000<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`<000002P3oool200000300oooo000a
0?ooo`030000003oool0oooo00X0oooo0`00000:0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0903oool2000001T0oooo0P00000V0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool0<03oool00380oooo00<000000?oo
o`3oool0303oool3000000L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00D0oooo0`00000>0?ooo`030000003oool0oooo0340oooo000c0?ooo`80
00003`3oool3000000D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00<0oooo0`00000?0?ooo`800000=03oool003D0oooo00<000000?ooo`3oool0
3`3oool3000000<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0;0?ooo`040000
003oool0oooo0?ooo`<000004@3oool00`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo
0?ooo`0A0?ooo`@000003@3oool00`000000oooo0?ooo`0X0?ooo`8000003`3oool2000002X0oooo
00<000000?ooo`3oool02`3oool4000001<0oooo00<000000?ooo`3oool0=@3oool003L0oooo0P00
000D0?ooo`<00000303oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0:0?ooo`<00000503oool2000003P0oooo000i
0?ooo`030000003oool0oooo01<0oooo100000090?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00L0oooo1000000E
0?ooo`030000003oool0oooo03P0oooo000j0?ooo`030000003oool0oooo0180oooo00@000000?oo
o`3oool0oooo0`0000060?ooo`030000003oool0oooo02/0oooo0P0000070?ooo`800000;@3oool0
0`000000oooo0?ooo`040?ooo`<000000`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo03T0oooo000k0?ooo`8000004`3oool00`000000oooo0?ooo`030?ooo`<00000103oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`800000?03oool003d0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`<0000000<0oooo0000003o
ool0;P3oool01@000000oooo0?ooo`3oool0000002l0oooo00<000000?ooo`0000000P0000070?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0?03oool003h0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`070?ooo`800000<03oool300000300oooo0P0000090?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0?@3oool003l0oooo0P00000A0?ooo`030000
003oool0oooo00T0oooo0`00000]0?ooo`030000003oool0000002d0oooo0`00000;0?ooo`030000
003oool0oooo00l0oooo0P0000100?ooo`00@@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`00000Y0?ooo`050000003oool0oooo0?ooo`000000
:@3oool300000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0400oooo00120?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`<00000903oool2000000D0oooo0P00000T0?ooo`<000001@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0@@3o
ool004<0oooo0P00000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool3
00000200oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0N0?ooo`<000001`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo0P0000140?ooo`00A@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool30000
01`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?ooo`<000002P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0A03oool004H0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0
oooo0`00000H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05P3oool3000000d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04D0
oooo00170?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0>0?ooo`<000004`3oool2000000l0oooo0P00000C0?ooo`<00000403oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0AP3oool004P0oooo0P00
000=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool3000000l0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`<000004P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00/0oooo0P0000190?ooo`00BP3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool3000000/0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`<000005@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0B@3oool004/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo0`0000060?oo
o`8000005`3oool2000000H0oooo0`00000H0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1:0?ooo`00C03oool2000000/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0H0?ooo`<000000P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00<000006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0
oooo0P00001=0?ooo`00CP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool06`3oool2000001d0oooo0P00000M0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1=0?ooo`00C`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool2000000040?ooo`00
00000000000001L0oooo0`0000000`3oool000000000000L0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1>0?ooo`00D03oool2000000T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo0`00
000A0?ooo`<000001P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01`3oool200000540oooo001B0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo0`00000;
0?ooo`<000002P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`1A0?ooo`00D`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool2000000h0oooo0`0000050?oo
o`<000003P3oool2000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0580oooo001D0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool5000001<0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P00001E0?ooo`00
EP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0A0?ooo`<0000000@0oooo00000000000000004`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1E0?ooo`00E`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`00
00004`3oool00`000000oooo0?ooo`0?0?ooo`<000001`3oool300000140oooo00<000000?ooo`3o
ool04@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0EP3oool005P0
oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool2000000l0
oooo0`00000=0?ooo`<000003`3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`800000F@3oool005X0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0303oool3000001<0oooo0`00000>0?ooo`03
0000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
05T0oooo001K0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000003P3oool00`00
0000oooo0?ooo`0:0?ooo`<000006@3oool3000000`0oooo00<000000?ooo`3oool0303oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo05X0oooo001L0?ooo`8000000`3oool01000
0000oooo0?ooo`00000<0?ooo`8000002P3oool3000001l0oooo0`00000:0?ooo`800000303oool0
10000000oooo0?ooo`0000030?ooo`800000G@3oool005h0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool3000002D0oooo0`00
00090?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`1M0?ooo`00G`3oool01`000000oooo0?ooo`3oool000000?ooo`0000002@3oool00`000000
oooo0?ooo`060?ooo`800000:`3oool2000000P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo000000030?ooo`030000003oool0oooo05h0oooo001P0?ooo`8000000P3oool2000000L0oooo
0P0000060?ooo`<00000;`3oool3000000H0oooo0P0000070?ooo`8000000P3oool200000640oooo
001R0?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`<00000
=@3oool3000000D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000006<0
oooo001S0?ooo`030000003oool0000000<000000P3oool010000000oooo0?ooo`3oool3000003/0
oooo0`0000030?ooo`030000003oool0oooo00@0000000<0oooo0000003oool0H`3oool006@0oooo
1`000000103oool000000000000000110?ooo`<0000000<0oooo0000000000001@00001U0?ooo`00
I03oool8000004L0oooo2000001U0?ooo`00I03ooomG000006D0oooo001T0?ooo`L00000B@3oool7
000006D0oooo001U0?ooo`D00000B`3oool5000006H0oooo001V0?ooo`<00000C@3oool3000006L0
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500054, -0.0255335, \
0.00383279, 0.00366225}}]
}, Open  ]],

Cell[TextData[{
  "Neben dem Rewiring-Verfahren gibt es noch ein weiteres Verfahren zur \
\[CapitalUDoubleDot]berf\[UDoubleDot]hrung dieser Struktur in einen \
Small-World-Graphen diskutieren: das Link-Adding-Verfahren. Dabei werden dem \
Backbone-Graphen zuf\[ADoubleDot]llig Verbindungen hinzugef\[UDoubleDot]gt. \
Wie zuvor definieren wir die Operationen auf der Ebene der Adjacency-Matrix. \
Das Vorgehen ist sehr einfach: Beginnend mit einem regul\[ADoubleDot]ren \
Backbone wird jeder m\[ODoubleDot]gliche Eintrag der Matrix abgefragt. Ist er \
Null und greift die Wahrscheinlichkeit ",
  StyleBox["p",
    FontSlant->"Italic"],
  ", so wird an dieser Stelle (und dem dazu gespiegelten Element) eine Eins \
eingef\[UDoubleDot]gt. Dabei beschr\[ADoubleDot]nkt sich die Abfrage auf die \
obere Dreiecksmatrix. Wie schon an vielen Stellen in den vorangegangenen \
Kapiteln ist die Wahrscheinlichkeitsabfrage gerade der Vergleich einer \
(zwischen 0 und 1 gleichverteilt gezogenen) Zufallszahl und der vorgegebenen \
Wahrscheinlichkeit. Man hat:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(addLinksSW[nn_, neigh_, prob_] := 
      Module[{aa1}, \[IndentingNewLine]aa1 = 
          backbone[nn, neigh]; \[IndentingNewLine]Do[
          If[aa1[\([ii, jj]\)] \[Equal] 0 && 
              Random[] < prob, {aa1[\([ii, jj]\)] = 1, 
              aa1[\([jj, ii]\)] = 1}], {ii, 1, nn}, {jj, 1, 
            ii - 1}]; \[IndentingNewLine]aa1]\)], "Input"],

Cell[TextData[{
  "Die Graphengr\[ODoubleDot]\[SZ]e, die Nachbarschaftsgr\[ODoubleDot]\[SZ]e \
und die Link-Adding-Wahrscheinlichkeit sind die Parameter dieser Routine. In \
einem regul\[ADoubleDot]ren Graphen mit 20 Knoten und einem Grad von 6, dem \
mit der Wahrscheinlichkeit ",
  StyleBox["p",
    FontSlant->"Italic"],
  "=0.05 Verbindungen hinzugef\[UDoubleDot]gt werden, erkennt man noch sehr \
deutlich die regul\[ADoubleDot]re Struktur, die von einigen Querverbindungen \
(",
  StyleBox["shortcuts",
    FontSlant->"Italic"],
  ") durchbrochen wird:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g4 = 
        FromAdjacencyMatrix[
          addLinksSW[20, 3, 0.05]];\)\), "\[IndentingNewLine]", 
    \(\(ShowGraph[g4];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.909091 0.0454545 0.909091 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.005 w
[ ] 0 setdash
.9323 .64046 m
.86773 .76718 L
s
.9323 .64046 m
.76718 .86773 L
s
.9323 .64046 m
.64046 .9323 L
s
.9323 .64046 m
.23282 .13227 L
s
.9323 .64046 m
.64046 .0677 L
s
.9323 .64046 m
.86773 .23282 L
s
.9323 .64046 m
.9323 .35954 L
s
.9323 .64046 m
.95455 .5 L
s
.86773 .76718 m
.76718 .86773 L
s
.86773 .76718 m
.64046 .9323 L
s
.86773 .76718 m
.5 .95455 L
s
.86773 .76718 m
.13227 .23282 L
s
.86773 .76718 m
.9323 .35954 L
s
.86773 .76718 m
.95455 .5 L
s
.76718 .86773 m
.64046 .9323 L
s
.76718 .86773 m
.5 .95455 L
s
.76718 .86773 m
.35954 .9323 L
s
.76718 .86773 m
.0677 .64046 L
s
.76718 .86773 m
.95455 .5 L
s
.64046 .9323 m
.5 .95455 L
s
.64046 .9323 m
.35954 .9323 L
s
.64046 .9323 m
.23282 .86773 L
s
.64046 .9323 m
.23282 .13227 L
s
.5 .95455 m
.35954 .9323 L
s
.5 .95455 m
.23282 .86773 L
s
.5 .95455 m
.13227 .76718 L
s
.5 .95455 m
.13227 .23282 L
s
.35954 .9323 m
.23282 .86773 L
s
.35954 .9323 m
.13227 .76718 L
s
.35954 .9323 m
.0677 .64046 L
s
.35954 .9323 m
.13227 .23282 L
s
.23282 .86773 m
.13227 .76718 L
s
.23282 .86773 m
.0677 .64046 L
s
.23282 .86773 m
.04545 .5 L
s
.13227 .76718 m
.0677 .64046 L
s
.13227 .76718 m
.04545 .5 L
s
.13227 .76718 m
.0677 .35954 L
s
.13227 .76718 m
.76718 .13227 L
s
.0677 .64046 m
.04545 .5 L
s
.0677 .64046 m
.0677 .35954 L
s
.0677 .64046 m
.13227 .23282 L
s
.04545 .5 m
.0677 .35954 L
s
.04545 .5 m
.13227 .23282 L
s
.04545 .5 m
.23282 .13227 L
s
.0677 .35954 m
.13227 .23282 L
s
.0677 .35954 m
.23282 .13227 L
s
.0677 .35954 m
.35954 .0677 L
s
.13227 .23282 m
.23282 .13227 L
s
.13227 .23282 m
.35954 .0677 L
s
.13227 .23282 m
.5 .04545 L
s
.23282 .13227 m
.35954 .0677 L
s
.23282 .13227 m
.5 .04545 L
s
.23282 .13227 m
.64046 .0677 L
s
.35954 .0677 m
.5 .04545 L
s
.35954 .0677 m
.64046 .0677 L
s
.35954 .0677 m
.76718 .13227 L
s
.5 .04545 m
.64046 .0677 L
s
.5 .04545 m
.76718 .13227 L
s
.5 .04545 m
.86773 .23282 L
s
.64046 .0677 m
.76718 .13227 L
s
.64046 .0677 m
.86773 .23282 L
s
.64046 .0677 m
.9323 .35954 L
s
.76718 .13227 m
.86773 .23282 L
s
.76718 .13227 m
.9323 .35954 L
s
.76718 .13227 m
.95455 .5 L
s
.86773 .23282 m
.9323 .35954 L
s
.86773 .23282 m
.95455 .5 L
s
.9323 .35954 m
.95455 .5 L
s
.025 w
.9323 .64046 Mdot
.86773 .76718 Mdot
.76718 .86773 Mdot
.64046 .9323 Mdot
.5 .95455 Mdot
.35954 .9323 Mdot
.23282 .86773 Mdot
.13227 .76718 Mdot
.0677 .64046 Mdot
.04545 .5 Mdot
.0677 .35954 Mdot
.13227 .23282 Mdot
.23282 .13227 Mdot
.35954 .0677 Mdot
.5 .04545 Mdot
.64046 .0677 Mdot
.76718 .13227 Mdot
.86773 .23282 Mdot
.9323 .35954 Mdot
.95455 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00SP3oool3000008l0oooo002=0?ooo`D00000SP3oool008`0oooo1`00002=0?ooo`00S03o
ool7000008d0oooo00260?oooa<00000Q`3oool007l0oooo1`0000000`3oool000000000000?0000
00030?ooo`000000000000D00000P03oool006H0oooo0`00000?0?ooo`L000001@3oool300000080
oooo0P0000030?ooo`<000000`3oool200000080oooo0`0000050?ooo`L000003`3oool3000006L0
oooo001U0?ooo`D00000203oool6000000T0oooo0`0000030?ooo`8000003@3oool2000000<0oooo
0`0000090?ooo`H00000203oool5000006H0oooo001T0?ooo`h00000303oool3000000@0oooo0P00
000A0?ooo`800000103oool3000000`0oooo3P00001U0?ooo`00I03ooomG000006D0oooo001T0?oo
o`d000001P3oool4000000H0oooo0P00000I0?ooo`8000001P3oool4000000H0oooo3@00001U0?oo
o`00HP3oool8000000L0oooo1`0000070?ooo`8000007@3oool2000000L0oooo1`0000070?ooo`P0
0000H`3oool00600oooo0P000000103oool000000000003oool3000000P0oooo0`0000040?ooo`L0
00008@3oool7000000@0oooo0`0000080?ooo`H0000000<0oooo000000000000H@3oool005h0oooo
0P000000103oool0000000000000000:0?ooo`<000002P3oool2000000030?ooo`000000000000D0
00005@3oool7000000030?ooo`000000000000X0oooo0`0000080?ooo`030000003oool000000080
000000<0oooo000000000000G`3oool005`0oooo0P0000020?ooo`030000003oool0000000P0oooo
0`00000;0?ooo`8000002P3oool6000000T0oooo1P00000:0?ooo`8000002`3oool3000000H0oooo
00D000000?ooo`000000oooo000000020?ooo`800000G@3oool005X0oooo0P0000020?ooo`800000
00<0oooo0000003oool0103oool4000000`0oooo0P00000B0?ooo`T000004P3oool2000000`0oooo
100000020?ooo`050000003oool0oooo0000003oool00P0000020?ooo`800000F`3oool005P0oooo
0P0000030?ooo`040000003oool0oooo000000<0oooo0`00000>0?ooo`800000403oool6000000D0
oooo1P00000@0?ooo`8000003P3oool400000080oooo00@000000?ooo`3oool000000`3oool20000
05T0oooo001F0?ooo`800000103oool01@000000oooo0?ooo`000000oooo00<000003`3oool20000
00/0oooo1`00000A0?ooo`L000002`3oool2000000l0oooo0`0000001@3oool000000?ooo`3oool0
000000@0oooo0P00001G0?ooo`00E03oool2000000@0oooo0P0000020?ooo`<00000403oool20000
00L0oooo1P00000O0?ooo`H000001`3oool2000000h0oooo00<000000?ooo`0000000P0000020?oo
o`800000103oool2000005D0oooo001B0?ooo`8000001@3oool00`000000oooo0000000200000140
oooo0P0000020?ooo`L00000:`3oool700000080oooo0P00000<0?ooo`030000003oool0oooo0080
oooo0`0000000`3oool000000?ooo`040?ooo`800000D`3oool00500oooo0P0000050?ooo`@00000
00<0oooo0000003oool03`3oool6000003T0oooo1P00000;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000`0000050?ooo`800000D@3oool004h0oooo0P0000040?ooo`<00000103o
ool00`000000oooo0?ooo`080?ooo`L00000A@3oool7000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`<00000103oool2000004l0oooo001<0?ooo`8000000`3oool3
000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3oool6000000<0oooo0P000019
0?ooo`8000000`3oool6000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000002
000000<0oooo0P00001=0?ooo`00BP3oool200000080oooo0`0000020?ooo`800000103oool70000
00L0oooo0P00001=0?ooo`8000001P3oool8000000@0oooo0P0000020?ooo`<000000P3oool20000
04/0oooo00180?ooo`80000000@0oooo0000000000000000103oool7000000`0oooo0P00001A0?oo
o`8000001@3oool00`000000oooo0?ooo`040?ooo`L00000103oool3000000030?ooo`0000000000
04T0oooo00110?ooo`<000000P3oool5000000030?ooo`000000000000D00000103oool00`000000
oooo0?ooo`090?ooo`800000E@3oool2000000<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`L0000000<0oooo0000000000000`0000020?ooo`<00000@P3oool00400oooo
300000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool2000005T0oooo
0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`3oool<00000440oooo000o0?ooo`L00000203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00L0oooo0P00001M0?ooo`<00000203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo1`0000100?ooo`00?`3oool7000000H0oooo0P0000060?ooo`030000003o
ool0oooo00H0oooo0P00001Q0?ooo`800000203oool00`000000oooo0?ooo`040?ooo`8000001P3o
ool700000400oooo000o0?ooo`L000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo0P00001T0?ooo`<000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo1`0000100?ooo`00?`3oool6000000040?ooo`000000oooo0?ooo`8000001`3oool0
0`000000oooo0?ooo`040?ooo`800000I`3oool010000000oooo0000000000060?ooo`030000003o
ool0oooo00D0oooo0P0000030?ooo`L00000@03oool003h0oooo1`0000020?ooo`800000203oool0
0`000000oooo0?ooo`030?ooo`800000J@3oool010000000oooo0?ooo`3oool2000000D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo000000020?ooo`H00000?`3oool003d0oooo0`000005
0?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`800000K03o
ool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`0000000000?P3oool003`0oooo00@000000?ooo`0000000000
1@3oool2000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000006h0
oooo00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`3oool0103oool010000000
oooo0000000000050?ooo`80000000<0oooo0000003oool0?03oool003/0oooo00@000000?ooo`00
000000001@3oool00`000000oooo000000040?ooo`80000000@0oooo0000003oool0oooo0P00001a
0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000?03o
ool003X0oooo00D000000?ooo`000000oooo000000030?ooo`8000000P3oool00`000000oooo0?oo
o`040?ooo`040000003oool00000000007<0oooo00<000000?ooo`3oool01`3oool2000000050?oo
o`000000oooo0?ooo`0000001P3oool2000000<0oooo00D000000?ooo`000000oooo0000000k0?oo
o`00>@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`@00000M@3oool00`000000oooo0?ooo`080?ooo`@000002@3oool01P000000
oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0>03oool003P0oooo00L000000?oo
o`3oool000000?ooo`000000oooo008000001P3oool010000000oooo0?ooo`3oool2000000<0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0:0?ooo`8000002P3oool2000000040?oo
o`000000oooo00000080oooo00<000000?ooo`3oool0=`3oool003L0oooo00P000000?ooo`3oool0
00000?ooo`000000oooo000000T0oooo0`0000060?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`02000000X0oooo0P0000020?ooo`040000003oool0
oooo000003P0oooo000f0?ooo`040000003oool0oooo00000080oooo0P0000090?ooo`<00000203o
ool200000780oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`<000002@3o
ool200000080oooo00@000000?ooo`3oool00000=`3oool003D0oooo00H000000?ooo`3oool0oooo
0000003oool2000000P0oooo0P0000000`3oool000000000000:0?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`040000003oool000000000
00P0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo03@0oooo000d0?ooo`06
0000003oool0oooo0?ooo`000000oooo0P0000070?ooo`8000000P3oool00`000000oooo0000000;
0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo008000001`3oool2000000030?ooo`000000oooo0080oooo00<00000
0?ooo`3oool0<`3oool003<0oooo00@000000?ooo`3oool0oooo100000060?ooo`8000000`3oool0
1@000000oooo0?ooo`3oool0000000/0oooo0P00001`0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool010000000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`000000
0P0000030?ooo`030000003oool0oooo0380oooo000b0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo06d0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`03
0000003oool0oooo0080oooo0P0000040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0<@3oool00340oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?oo
o`8000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo0P00001^0?oo
o`030000003oool0000000h0oooo00<000000?ooo`3oool00`3oool200000080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0300oooo000`0?ooo`040000003oool0oooo
0?ooo`8000000`3oool010000000oooo0000000000060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`1[0?ooo`800000403oool00`000000oooo0?oo
o`040?ooo`80000000<0oooo0000003oool00P3oool2000000<0oooo00<000000?ooo`3oool0;`3o
ool002l0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`<000001`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0JP3oool200000140oooo00<0
00000?ooo`3oool01@3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo02h0oooo000^
0?ooo`030000003oool0oooo0080000000@0oooo0000003oool0oooo0P0000080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03P3oool2000006T0oooo00<000000?ooo`0000004P3o
ool00`000000oooo0?ooo`060?ooo`8000000P3oool010000000oooo0000000000020?ooo`030000
003oool0oooo02d0oooo000]0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000
0P0000080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`1U0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`050?ooo`06
0000003oool000000000003oool000000P3oool010000000oooo0?ooo`00000^0?ooo`00;03oool0
10000000oooo0?ooo`0000020?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<000000P3oool010000000oooo0?ooo`00000]0?ooo`00:`3oool010000000oooo0000
000000020?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0403oool200000680oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool200000080oooo
0P0000000`3oool000000?ooo`0[0?ooo`00:P3oool00`000000oooo000000020?ooo`<00000103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0`0000020?ooo`030000003o
ool0000002/0oooo000Y0?ooo`<0000000D0oooo000000000000oooo000000040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`800000G@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`050000003oool000000000003oool00`00000Z0?ooo`00903o
ool3000000040?ooo`00000000000?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo05T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000030?oo
o`000000000000<000009P3oool002<0oooo200000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo1`00
000U0?ooo`008P3oool7000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool2000005H0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`L00000903oool00280oooo1`0000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000060?ooo`040000003oool0
oooo0?ooo`L00000903oool00280oooo1`0000040?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo0000000I0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo
000000050?ooo`040000003oool0oooo0?ooo`L00000903oool002<0oooo1P0000030?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`030000003oool0oooo01L0
oooo0P00001?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05@3oool010000000
oooo0?ooo`0000060?ooo`040000003oool0oooo0?ooo`D000009@3oool002@0oooo10000000103o
ool000000?ooo`0000060?ooo`040000003oool0oooo000001`0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3o
ool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo0?ooo`@000009@3oool002<0oooo
0P0000000`3oool00000000000020?ooo`8000001@3oool010000000oooo0?ooo`00000N0?ooo`03
0000003oool0oooo01T0oooo0P00001:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo000000060?ooo`030000003oool0oooo00@0oooo0P00000T0?ooo`00
8`3oool200000080oooo0P000000103oool000000?ooo`0000040?ooo`030000003oool0000001l0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo000000060?ooo`030000003oool0oooo00<0
oooo0P00000T0?ooo`008P3oool300000080oooo0`0000030?ooo`060000003oool0oooo0000003o
ool000008@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`8000001`3oool00`000000oooo0?ooo`020?oo
o`<000008`3oool00280oooo0`0000020?ooo`<00000103oool400000280oooo00<000000?ooo`3o
ool0703oool2000004<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`80
00001`3oool010000000oooo0?ooo`3oool3000002<0oooo000Q0?ooo`040000003oool000000000
00<0oooo0P0000050?ooo`800000903oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`0Q0?ooo`008@3oool20000
00040?ooo`000000oooo0?ooo`80000000<0oooo0000003oool00`3oool010000000oooo00000000
000R0?ooo`030000003oool0oooo01h0oooo0P00000n0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0000003oool0
0P00000R0?ooo`00803oool010000000oooo0000000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0603oool2000000L0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`0P0?ooo`00
803oool010000000oooo0000000000020?ooo`070000003oool0oooo0000003oool000000?ooo`02
000000D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0H0?ooo`8000001P3oool0
0`000000oooo0?ooo`02000000030?ooo`000000oooo0200oooo000O0?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool00000008000001`3oool200000200oooo00<0
00000?ooo`3oool0803oool2000003L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool000000200
oooo000O0?ooo`040000003oool000000?ooo`800000103oool00`000000oooo00000002000000T0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0000000H0
oooo0P000000103oool000000?ooo`00000P0?ooo`007P3oool01P000000oooo0?ooo`000000oooo
000000H0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo01P0oooo00@000000?ooo`3oool000001P3oool00`000000oooo000000020?ooo`030000003o
ool0oooo01d0oooo000N0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool2
000000030?ooo`000000000000/0oooo0P00000M0?ooo`030000003oool0oooo02<0oooo0P00000`
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`00
00050?ooo`060000003oool0oooo0000003oool000007`3oool001d0oooo00D000000?ooo`3oool0
00000?ooo`02000000@0oooo00H000000?ooo`00000000000?ooo`00000=0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0603oool01@000000oooo0?ooo`3oool0000000@0oooo0P00
00001@3oool000000?ooo`3oool0000001h0oooo000M0?ooo`030000003oool0oooo00<00000103o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000001/0oooo
00<000000?ooo`3oool09@3oool2000002/0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0H0?ooo`050000003oool0oooo0?ooo`000000103oool300000080oooo00<000000?ooo`3o
ool0703oool001`0oooo00D000000?ooo`3oool000000?ooo`02000000<0oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P000000
1@3oool000000?ooo`3oool0000001d0oooo000L0?ooo`030000003oool0oooo0080000000D0oooo
0000003oool0oooo000000040?ooo`8000000`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0000003oool00P0000020?ooo`030000003oool0oooo01/0oooo000K0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo000000040?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool03P3oool2000001T0oooo00<000000?ooo`3oool09`3oool2000002@0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001`0oooo000K0?ooo`04
0000003oool0oooo000000<0oooo0P0000050?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool00`3oool2000000<0oooo00@000000?ooo`3oool00000703oool001X0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo008000000P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000B0?ooo`80
00005P3oool00`000000oooo0?ooo`0Z0?ooo`8000007@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0200000080
oooo00<000000?ooo`3oool06@3oool001T0oooo00L000000?ooo`3oool000000?ooo`000000oooo
008000001@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000503oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool2
000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool0603oool001T0oooo00<00000
0?ooo`3oool00P000000103oool000000?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`800000503oool00`000000oooo0?oo
o`0/0?ooo`800000603oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0000003oool200000080oooo00<000000?ooo`3oool0
603oool001P0oooo00D000000?ooo`3oool000000?ooo`0200000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`02000000050?ooo`000000oooo0?ooo`0000006@3oool001P0oooo00<000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0000001T0oooo000G0?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0E0?ooo`8000004P3oool00`000000oooo0?ooo`0^0?ooo`8000004@3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool00000603oool001L0oooo00@0
00000?ooo`000000oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`000000103oool2000000040?ooo`000000oooo
000001P0oooo000F0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo
00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000000G0?ooo`005P3oool2
000000040?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool200000100oooo00<000000?ooo`3oool0
<03oool2000000X0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0H0?ooo`050000
003oool0oooo0?ooo`000000103oool010000000oooo0000003oool2000001L0oooo000E0?ooo`04
0000003oool0000000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000<
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0080000000<0oooo0000003oool05@3oool001D0oooo0`0000030?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01T0oooo0P00000>0?ooo`030000003oool0oooo0380oooo0P0000050?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo0?ooo`<000005P3oool00180oooo1@0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`0000003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000@P3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000D0oooo00@000000?oo
o`3oool0oooo1@00000C0?ooo`004@3oool5000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0000000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`000000A03oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool50000
0180oooo000@0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000l0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`8000002`3oool00`000000
oooo0?ooo`0e0?ooo`800000A@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool0oooo1`00000A0?ooo`00403oool700000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03<0oooo00@000000?oo
o`3oool00000A03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool01`00000A0?ooo`00403oool700000080oooo00<000000?ooo`3oool00`3oool20000
0100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool05`3oool00`000000oooo000000050?ooo`030000003oool0oooo
00L000004@3oool00140oooo1@0000030?ooo`030000003oool0oooo00<0oooo0P00000A0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool07P3oool2000000T0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`040?ooo`800000@P3oool00`000000oooo0?ooo`0H0?ooo`80
00001@3oool010000000oooo0?ooo`3oool500000180oooo000B0?ooo`<00000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool05`3oool2000000D0
oooo00<000000?ooo`3oool00P3oool3000001<0oooo000B0?ooo`<000000`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0P0?ooo`8000001`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo
0P0000100?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`3oool3000001<0oooo000B0?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`800000
4`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
oooo0`00000C0?ooo`004P3oool3000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`3oool3000001<0oooo000B0?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`800000
503oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo0P0000040?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0403oool2000003h0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<000004`3oool00180oooo0`00
00020?ooo`030000003oool0oooo00<0oooo0P00000E0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01L0oooo0P00
00050?ooo`030000003oool0oooo00<000004`3oool00180oooo0`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo02@0oooo0P0000020?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01H0oooo0P0000050?ooo`030000003oool0
oooo00<000004`3oool00140oooo00@000000?ooo`000000oooo0P0000050?ooo`030000003oool0
000001D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0V0?ooo`040000003oool0
oooo000002H0oooo00<000000?ooo`3oool05`3oool2000003/0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo000000050?ooo`80000000<0oooo0000000000004`3oool00140oooo00@00000
0?ooo`000000oooo0P0000040?ooo`040000003oool0oooo000001H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`000000
1@3oool2000000040?ooo`000000oooo00000180oooo000A0?ooo`040000003oool000000?ooo`80
0000103oool00`000000oooo0000000G0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool09`3oool3000002<0oooo00<000000?ooo`3oool0703oool2000003T0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo000000040?ooo`80000000@0oooo0000003oool000004P3oool00140
oooo00D000000?ooo`000000oooo000000040?ooo`040000003oool0oooo000001L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`0000001@3oool01@000000oooo0000003oool000000180oooo000A0?ooo`050000003oool0
00000?ooo`000000103oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`000000oooo0000000B0?ooo`004@3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0:03oool3000001d0oooo00<000000?ooo`3oool08`3oool2000003L0oooo00<00000
0?ooo`3oool0503oool010000000oooo0?ooo`0000040?ooo`050000003oool000000?ooo`000000
4P3oool00140oooo00<000000?ooo`0000000P0000030?ooo`050000003oool0oooo0?ooo`000000
603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<000000?ooo`000000
6`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
503oool01@000000oooo0?ooo`3oool0000000<0oooo0`0000000`3oool000000?ooo`0A0?ooo`00
403oool00`000000oooo0?ooo`02000000040?ooo`000000oooo000000@0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool00P00000H0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo000000000002
0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003oool0oooo0080000000@0oooo0000
003oool00000103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0:@3oool01@000000oooo0?ooo`3oool0000001H0oooo00<000000?ooo`3oool0:P3o
ool2000003@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool000000?ooo`8000000P3oool00`000000oooo0?ooo`0?0?ooo`00403oool00`000000oooo0?oo
o`02000000030?ooo`000000000000@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0C0?ooo`080000003oool0oooo0?ooo`000000oooo0000003oool200000080oooo00<000000?oo
o`3oool03`3oool00100oooo00@000000?ooo`3oool000000P3oool2000000@0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool00P3oool200000140oooo00<000000?ooo`3oool0;`3oool200000380oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool010000000oooo0?ooo`00000A
0?ooo`00403oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`040000003oool0oooo00000140oooo000@0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo
000@0?ooo`080000003oool000000000003oool000000?ooo`0000040?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00D0oooo0P00000:0?ooo`030000003oool0oooo03H0oooo0P00000`0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000000`3oool000000?ooo`0@0?oo
o`003`3oool00`000000oooo0?ooo`02000000040?ooo`000000oooo000000@0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`000000oooo0P0000020?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo
00<000000P3oool01@000000oooo0?ooo`3oool0000001d0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00L0oooo0P0000050?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0A0?ooo`080000003oool0
oooo0?ooo`000000oooo0000003oool200000080oooo00<000000?ooo`3oool03P3oool000l0oooo
00@000000?ooo`000000oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000007P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0203oool01@00
0000oooo0?ooo`3oool0000003l0oooo0P00000]0?ooo`030000003oool0oooo0140oooo00D00000
0?ooo`3oool0oooo000000020?ooo`80000000@0oooo0000003oool00000403oool000l0oooo00D0
00000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000007P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool00`000000
oooo000000120?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool000000080oooo0P000000103oool000000?ooo`00000@0?ooo`003`3oool01@00
0000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000000N0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`800000@`3o
ool2000002/0oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`000000oooo0000000@0?ooo`003`3oool2000000030?ooo`000000000000<0oooo
00D000000?ooo`3oool0oooo0000000O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000004@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`0200000100oooo000>0?ooo`040000003oool000000?ooo`800000103oool0
10000000oooo0?ooo`00000O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool00000
103oool2000000030?ooo`00000000000100oooo000>0?ooo`060000003oool000000000003oool0
0000103oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0P0000130?oo
o`800000:@3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000@0oooo0P000000
103oool000000?ooo`00000?0?ooo`003P3oool2000000040?ooo`000000oooo000000@0oooo00<0
00000?ooo`0000008@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000000@0oooo00@0
00000?ooo`000000oooo0P00000?0?ooo`003P3oool300000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000000Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo0P0000130?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool03P3oool00`000000oooo000000040?ooo`040000003o
ool000000?ooo`8000003`3oool000h0oooo0`0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000008@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo00@0
00000?ooo`3oool000003P3oool00`000000oooo0?ooo`110?ooo`8000009P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`00000?0?ooo`003P3o
ool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000R0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0000000@0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00`00000?0?ooo`003P3oool2000000<0oooo00<00000
0?ooo`3oool00`3oool200000280oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0100oooo0P0000130?ooo`800000903oool00`000000oooo0?ooo`0=
0?ooo`8000001@3oool010000000oooo0?ooo`3oool2000000l0oooo000;0?ooo`@00000103oool0
0`000000oooo0?ooo`030?ooo`8000008P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo02L0oooo0P00000D0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0<0?ooo`8000001@3oool010000000oooo0?ooo`3oool4000000d0oooo000:
0?ooo`D00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000001@0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`3oool5000000`0oooo00090?ooo`L000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0T0?ooo`050000003oool0oooo0?ooo`0000005@3oool2000004<0oooo
0P00000R0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`07000000/0oooo00090?ooo`L000000`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L000002`3oool000T0oooo1`0000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`800000@`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
000000/0oooo000:0?ooo`D00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`110?ooo`800000803oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo1@00000<
0?ooo`002`3oool4000000@0oooo00<000000?ooo`3oool00`3oool2000002@0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool02@3oool2000000D0oooo00@000000?ooo`3oool0oooo1000000=0?ooo`003P3oool20000
00<0oooo00<000000?ooo`3oool00`3oool2000002D0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool20000
04<0oooo0P00000N0?ooo`030000003oool0oooo00P0oooo0P0000050?ooo`040000003oool0oooo
0?ooo`8000003`3oool000h0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000009@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool00`00000?0?ooo`003P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000U0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`03000000l0oooo000>0?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000002H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool2000004<0oooo0P00000K0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`000000103oool010000000oooo0000003oool2000000l0
oooo000>0?ooo`80000000@0oooo0000003oool00000103oool00`000000oooo0000000V0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`000000103oool010000000oooo0000003oool20000
00l0oooo000>0?ooo`060000003oool000000000003oool00000103oool010000000oooo0?ooo`00
000U0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo01`0oooo0P0000130?ooo`8000006@3oool00`000000oooo0?oo
o`050?ooo`040000003oool0oooo000000@0oooo0P000000103oool000000?ooo`00000?0?ooo`00
3P3oool010000000oooo0000003oool2000000@0oooo00@000000?ooo`3oool000009P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo0P0000000`3oool000000000000@
0?ooo`003`3oool2000000030?ooo`000000000000<0oooo00D000000?ooo`3oool0oooo0000000V
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00800000403oool000l0oooo00D000000?ooo`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0N0?ooo`800000@`3oool2000001L0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`00
0000oooo0000000@0?ooo`003`3oool01@000000oooo0000003oool0000000<0oooo00D000000?oo
o`3oool0oooo0000000W0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`80000000@0oooo0000003oool00000403oool000l0oooo00@000000?ooo`000000oooo
0P0000020?ooo`050000003oool0oooo0?ooo`0000009`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool2000000040?ooo`000000oooo00000100oooo000?0?oo
o`030000003oool0oooo00<000000P3oool01@000000oooo0?ooo`3oool0000002L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0803oool2000004<0oooo0P00000D0?ooo`030000003oool0oooo0080oooo00P00000
0?ooo`3oool0oooo0000003oool000000?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`00
3`3oool00`000000oooo0?ooo`02000000040?ooo`000000oooo000000@0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool04P3oool010000000oooo0?ooo`0000040?ooo`040000003oool000000?ooo`8000000P3oool0
0`000000oooo0?ooo`0>0?ooo`00403oool020000000oooo000000000000oooo0000003oool00000
103oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0280oooo0P0000130?ooo`800000
4P3oool010000000oooo0?ooo`0000040?ooo`8000000P3oool2000000030?ooo`000000oooo0100
oooo000@0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0?0?ooo`00403oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool03`3oool00`000000oooo000000040?ooo`8000000P3oool01000
0000oooo0?ooo`00000A0?ooo`00403oool010000000oooo0?ooo`0000020?ooo`800000103oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02D0oooo0P0000130?ooo`800000403oool2
000000@0oooo0P0000020?ooo`040000003oool0oooo00000140oooo000@0?ooo`030000003oool0
oooo0080000000<0oooo000000000000103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0=0?ooo`8000000`3oool0
10000000oooo0000003oool200000080oooo00<000000?ooo`3oool03`3oool00100oooo00<00000
0?ooo`3oool00P000000103oool000000?ooo`0000040?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00`0oooo0P0000030?ooo`040000
003oool000000?ooo`8000000P3oool00`000000oooo0?ooo`0?0?ooo`00403oool00`000000oooo
0?ooo`02000000040?ooo`000000oooo000000@0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0?0?ooo`040000003oool0oooo000002P0oooo00<000000?ooo`3oool09`3oool20000
04<0oooo0P00000<0?ooo`8000000P3oool01@000000oooo0?ooo`000000oooo008000000P3oool0
0`000000oooo0?ooo`0?0?ooo`004@3oool00`000000oooo00000002000000<0oooo00D000000?oo
o`3oool0oooo0000000X0?ooo`030000003oool0oooo0100oooo0P00000Y0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`090?ooo`050000003oool0
00000?ooo`0000000`3oool3000000030?ooo`000000oooo0140oooo000A0?ooo`050000003oool0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000002P0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo0P0000130?ooo`800000
2@3oool010000000oooo0000000000040?ooo`050000003oool000000?ooo`0000004P3oool00140
oooo00D000000?ooo`000000oooo000000040?ooo`040000003oool0oooo000002T0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000@0oooo00D0
00000?ooo`000000oooo0000000B0?ooo`004@3oool01@000000oooo0000003oool0000000@0oooo
00@000000?ooo`3oool00000:@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
02/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`0000000000103oool01@000000oooo0000003oool000000180oooo000A
0?ooo`040000003oool000000?ooo`800000103oool00`000000oooo0000000Y0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02`0oooo0P0000130?ooo`8000001@3oool01@000000oooo0000003oool000000080oooo
0P000000103oool000000?ooo`00000B0?ooo`004@3oool010000000oooo0000003oool2000000@0
oooo00@000000?ooo`3oool00000:@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
0480oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool00P00
0000103oool000000?ooo`00000B0?ooo`004@3oool010000000oooo0000003oool2000000D0oooo
00<000000?ooo`000000:@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0480oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000000003oool00P00000C
0?ooo`004P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000Y0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo02h0oooo0P0000130?ooo`@00000103oool200000080oooo0`00000C0?oo
o`004P3oool300000080oooo00<000000?ooo`3oool00`3oool2000002X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`120?ooo`8000001@3oool00`000000oooo0?ooo`03000001<0
oooo000B0?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`800000:P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0`0?ooo`800000@P3oool3000000@0oooo00<000000?ooo`3oool00`00000C0?ooo`004P3o
ool3000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0?`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool000000?ooo`<000004`3oool00180oooo0`0000030?ooo`030000003oool0oooo00<0oooo
0P00000Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`020?ooo`060000003oool000000?ooo`000000oooo0`00000C0?ooo`004P3oool3000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0X0?ooo`050000003oool0oooo0?oo
o`000000403oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03<0oooo0P00000m0?oo
o`030000003oool0oooo00<0oooo0P0000020?ooo`@000004`3oool00180oooo0`0000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`00000A0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0i0?oo
o`8000001@3oool010000000oooo0000003oool4000001<0oooo000A0?ooo`D000000`3oool00`00
0000oooo0?ooo`030?ooo`800000:P3oool2000001<0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo03P0oooo0P0000050?ooo`030000003oool0oooo
00H000004P3oool00100oooo1`0000020?ooo`030000003oool0oooo00<0oooo0P00000Z0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0e0?ooo`80
0000=`3oool00`000000oooo000000050?ooo`030000003oool0oooo00L000004@3oool00100oooo
1`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000:03oool2000001D0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0700000140oooo000@0?ooo`P000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000002L0oooo00@000000?ooo`3oool00000
503oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03L0oooo0P00000c0?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool0oooo1`00000A0?ooo`004@3oool500000080
oooo0`0000050?ooo`030000003oool0000002D0oooo00D000000?ooo`3oool0oooo0000000E0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool500000180oooo000B0?ooo`D0
00000`3oool400000080oooo00<000000?ooo`000000903oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo02h0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`3oool5
000001<0oooo000E0?ooo`<000000`3oool00`000000oooo0?ooo`0300000080oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0j0?ooo`800000;P3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo0?ooo`<000005P3oool001D0oooo00@000000?ooo`00000000000P3o
ool00`000000oooo0?ooo`020?ooo`@000008@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo02X0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00800000
00<0oooo0000003oool05@3oool001H0oooo0P000000103oool000000?ooo`0000040?ooo`040000
003oool0oooo0?ooo`<000007@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0l0?ooo`800000:P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00@000000?ooo`000000oooo0P00000G0?ooo`005P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo
0`00000I0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000005`3o
ool001L0oooo00@000000?ooo`000000oooo0P0000040?ooo`050000003oool0oooo0?ooo`000000
103oool3000001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0U0?ooo`050000
003oool0oooo0?ooo`000000103oool2000000040?ooo`000000oooo000001P0oooo000G0?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00L0oooo0`00000A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo03h0oooo0P00000T0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000001P0oooo000H
0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00L0oooo0`00000=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0000000I0?ooo`00603oool01@000000oooo0?ooo`000000oooo008000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo100000080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00800000
00D0oooo0000003oool0oooo0000000I0?ooo`006@3oool00`000000oooo0?ooo`02000000040?oo
o`000000oooo000000D0oooo00<000000?ooo`3oool03@3oool3000000@0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0@@3oool2000001l0oooo00<000000?ooo`3oool00`3oool010000000oooo0000003oool20000
0080oooo00<000000?ooo`3oool0603oool001T0oooo00L000000?ooo`3oool000000?ooo`000000
oooo008000001@3oool00`000000oooo0?ooo`0@0?ooo`@000004P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00@0oooo0P000000103oool000000?ooo`0000020?ooo`030000003o
ool0oooo01P0oooo000J0?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0140oooo1000000@0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`130?ooo`8000006`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`0I0?ooo`006P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0080oooo0`00000=0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool06@3o
ool001/0oooo00@000000?ooo`3oool000000`3oool2000000D0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`060?ooo`<000002`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00<0oooo0P0000030?ooo`040000003oool0oooo000001`0oooo000K0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo000000040?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool02P3oool3000000P0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo04D0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001`0oooo000L0?ooo`030000
003oool0oooo0080000000D0oooo0000003oool0oooo000000040?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03P3oool3000000D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0000003oool00P0000020?ooo`030000003oool0oooo
01/0oooo000L0?ooo`050000003oool0oooo0000003oool00P0000030?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`0B0?ooo`<000000`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000001@3oool000000?oo
o`3oool0000001d0oooo000M0?ooo`030000003oool0oooo00<00000103oool01@000000oooo0?oo
o`3oool0000000X0oooo00<000000?ooo`3oool05P3oool4000001P0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`180?ooo`800000403oool01@000000oooo0?ooo`3oool0000000@0
oooo0`0000020?ooo`030000003oool0oooo01`0oooo000M0?ooo`050000003oool0oooo0000003o
ool00P0000040?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool06P3oool30000
01L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
00`0oooo00D000000?ooo`3oool0oooo000000040?ooo`80000000D0oooo0000003oool0oooo0000
000N0?ooo`007P3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000000800000503o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04X0oooo0P00000<0?ooo`040000003o
ool0oooo000000D0oooo00H000000?ooo`3oool000000?ooo`00000O0?ooo`007P3oool01P000000
oooo0?ooo`000000oooo000000H0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0080oooo0`00000B0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`0M0?ooo`007`3oool010000000oooo0000003o
ool2000000H0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00D0oooo0`00000?0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`070?ooo`030000003oool0000000H0oooo0P000000103oool000000?oo
o`00000P0?ooo`007`3oool01`000000oooo0000003oool000000?ooo`0000001P3oool2000000<0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`<000003@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo04`0oooo0P0000060?ooo`030000003oool0000000H0
oooo00L000000?ooo`000000oooo0000003oool000000200oooo000P0?ooo`040000003oool00000
00000080oooo00<000000?ooo`3oool0103oool2000000030?ooo`000000oooo0280oooo00<00000
0?ooo`3oool02P3oool3000000X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo0080000000<0oooo
0000003oool0803oool00200oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`05
0?ooo`800000903oool00`000000oooo0?ooo`0=0?ooo`<00000203oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo04h0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`030000003o
ool0oooo0080000000<0oooo0000003oool0803oool00240oooo0P0000001@3oool000000?ooo`3o
ool0000000H0oooo0P00000U0?ooo`030000003oool0oooo00l0oooo0`0000050?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0CP3oool2000000030?ooo`000000oooo00H0oooo00D0
00000?ooo`3oool000000?ooo`0200000280oooo000Q0?ooo`040000003oool00000000000<0oooo
00<000000?ooo`3oool00P3oool010000000oooo00000000000T0?ooo`030000003oool0oooo0180
oooo0`0000030?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool08@3oool00280
oooo0`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool2000002<0oooo00<000000?oo
o`3oool05@3oool4000002/0oooo00<000000?ooo`3oool0CP3oool4000000D0oooo00@000000?oo
o`3oool0oooo0`00000S0?ooo`008P3oool3000000@0oooo00<000000?ooo`000000103oool00`00
0000oooo0000000S0?ooo`030000003oool0oooo01L0oooo0`00000Y0?ooo`030000003oool0oooo
04d0oooo0P0000030?ooo`050000003oool0oooo0?ooo`000000103oool3000002<0oooo000S0?oo
o`8000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool000000280oooo00<000000?oo
o`3oool0603oool00`000000oooo00000002000002L0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo000000040?ooo`030000003oool0000000D0oooo0P00000T0?ooo`008`3oool2000000@0
oooo0P0000060?ooo`040000003oool0oooo00000240oooo00<000000?ooo`3oool06@3oool01000
0000oooo0?ooo`3oool4000002<0oooo00<000000?ooo`3oool0BP3oool00`000000oooo00000006
0?ooo`8000001@3oool2000002@0oooo000T0?ooo`<0000000D0oooo0000003oool0oooo00000006
0?ooo`040000003oool0oooo00000240oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`050?ooo`<000008@3oool00`000000oooo0?ooo`180?ooo`040000003oool0oooo000000H0oooo
00@000000?ooo`000000oooo1000000U0?ooo`008`3oool5000000@0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool000000200oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`070?ooo`<000007P3oool00`000000oooo0?ooo`170?ooo`040000003oool0oooo0000
00H0oooo00@000000?ooo`3oool0oooo1@00000U0?ooo`008P3oool7000000@0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool0000001l0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0:0?ooo`<00000703oool00`000000oooo0?ooo`150?ooo`050000003oool0
oooo0?ooo`0000001@3oool010000000oooo0?ooo`3oool7000002@0oooo000R0?ooo`L00000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00`0oooo0`00000I0?ooo`030000003o
ool0oooo04@0oooo00D000000?ooo`3oool0oooo000000060?ooo`040000003oool0oooo0?ooo`L0
0000903oool00280oooo1`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
3`3oool3000001L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool7000002@0oooo000S0?ooo`L000001@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0140oooo0`00000D0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo1P00000U0?ooo`00903oool3000000030?ooo`0000000000008000000`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01@0oooo0`00000B0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo0?ooo`L000009P3oool002T0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool05P3oool3000000l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@00000Z0?ooo`00:P3oool01000
0000oooo0000003oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool3
000000d0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00P000000?ooo`00000000000?ooo`000000oooo000002/0oooo000[0?ooo`050000
003oool000000000003oool00`0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo0`00000:0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<0
000000D0oooo000000000000oooo0000000/0?ooo`00;03oool010000000oooo0?ooo`0000020?oo
o`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`<00000203oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`040000003oool0
oooo000002d0oooo000]0?ooo`040000003oool0oooo00000080oooo0`0000000`3oool000000?oo
o`070?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0P0?ooo`<000001@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`0000020?ooo`040000003oool0oooo000002h0oooo000^0?ooo`030000003o
ool0oooo0080000000<0oooo0000003oool00`0000080?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0S0?ooo`<000000`3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo00H0oooo0`0000000`3oool000000?ooo`0200000080oooo00<0
00000?ooo`3oool0;@3oool002l0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`800000203o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool09@3o
ool4000003L0oooo00<000000?ooo`3oool01P3oool2000000<0oooo0P0000030?ooo`030000003o
ool0oooo02h0oooo000`0?ooo`040000003oool0oooo0?ooo`8000000`3oool3000000L0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02P0oooo0`00
000d0?ooo`030000003oool0oooo00D0oooo0`0000030?ooo`8000000`3oool00`000000oooo0?oo
o`0_0?ooo`00<@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo0P00
00060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0000000800000<03oool00`000000oooo0?ooo`040?ooo`80000000<0
oooo0000003oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0300oooo000b
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool2000000D0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02P0oooo00@0
00000?ooo`3oool0oooo0`00000/0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0<@3oool003<0oooo00@000000?ooo`3oool0
oooo100000050?ooo`800000103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`040?ooo`<00000:03oool00`000000
oooo0?ooo`020?ooo`800000103oool00`000000oooo00000002000000<0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo00H000000?ooo`3oool0oooo0000003oool2000000H0oooo0P0000030?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00H0oooo0`00000T0?ooo`040000003oool0oooo0?ooo`8000001P3oool2
000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0<`3oool003D0oooo00H000000?oo
o`3oool0oooo0000003oool2000000L0oooo0P0000020?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo0`00
000P0?ooo`030000003oool0oooo008000001`3oool2000000030?ooo`000000oooo0080oooo00<0
00000?ooo`3oool0=03oool003H0oooo00@000000?ooo`3oool000000P3oool2000000P0oooo0P00
00000`3oool000000?ooo`0B0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0;0?ooo`<00000703oool010000000oooo0000000000080?ooo`800000
0P3oool010000000oooo0?ooo`00000g0?ooo`00=`3oool020000000oooo0?ooo`000000oooo0000
003oool000002@3oool300000180oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00h0oooo1000000G0?ooo`<000002@3oool200000080oooo00@00000
0?ooo`3oool00000>03oool003P0oooo00L000000?ooo`3oool000000?ooo`000000oooo00800000
2@3oool200000180oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0140oooo0`00000C0?ooo`8000002@3oool2000000040?ooo`000000oooo00000080
oooo00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool00P0000030?ooo`030000
003oool0oooo00P0oooo0P00000@0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0D0?ooo`<000003P3oool2000000X0oooo00H000000?ooo`3oool0
00000?ooo`0000020?ooo`030000003oool0oooo03P0oooo000j0?ooo`050000003oool000000?oo
o`0000000`3oool2000000T0oooo0`00000>0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0F0?ooo`<000002@3oool3000000T0oooo0P0000030?oo
o`050000003oool000000?ooo`000000>`3oool003/0oooo00@000000?ooo`00000000001@3oool0
0`000000oooo0?ooo`070?ooo`040000003oool00000000000d0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo0`0000040?ooo`80000000<0
oooo0000003oool0203oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000
?03oool003`0oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo008000002`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool06`3oool400000080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`80000000<0oooo0000003oool0?03oool003d0oooo0`0000060?ooo`800000203o
ool010000000oooo0?ooo`3oool2000000T0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo01/0oooo0P000000103oool000000000000000080?ooo`80
00001@3oool010000000oooo00000000000n0?ooo`00?P3oool3000000L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`800000203oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0603oool2000000@0oooo00<000000?ooo`00
00000P0000040?ooo`030000003oool0oooo00D0oooo0`00000o0?ooo`00?`3oool5000000D0oooo
0P0000070?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0F0?ooo`8000001@3oool00`000000oooo
0?ooo`030?ooo`@000001@3oool500000400oooo00100?ooo`D000001P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0C0?ooo`8000001P3oool00`000000oooo0?oo
o`050?ooo`030000003oool00000008000000P3oool500000440oooo000o0?ooo`L000001P3oool2
000000H0oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo0P0000070?ooo`030000003oool0
oooo00@0oooo0P0000050?ooo`P00000@03oool003l0oooo1`0000080?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000oooo0200oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0>0?ooo`800000203oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo1`0000100?ooo`00?`3oool=000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`8000008@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00`0oooo0P0000090?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool0oooo3@0000100?ooo`00@03oool5000000030?ooo`000000000000<0000000<0oooo00000000
00001@0000040?ooo`030000003oool0oooo00P0oooo0P00000P0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool02@3oool2000000X0oooo00<000000?ooo`3oool00P3oool700000003
0?ooo`000000000000<0000000<0oooo0000000000000`0000110?ooo`00@@3oool3000000@0oooo
0P000000103oool000000000000000040?ooo`L000002@3oool010000000oooo00000000000N0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool01`3oool2000000/0oooo1`0000040?oo
o`<0000000<0oooo000000000000103oool300000480oooo001:0?ooo`8000000P3oool300000080
oooo0P0000040?ooo`L000000P3oool010000000oooo0?ooo`3oool2000001d0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`040?ooo`8000001P3oool7000000@0oooo0P0000020?oo
o`<000000P3oool2000004/0oooo001<0?ooo`8000000`3oool3000000030?ooo`000000oooo00<0
oooo00<000000?ooo`3oool00`3oool600000080oooo0P00000K0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool00P3oool200000080oooo1P0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000P0000030?ooo`800000C@3oool004h0oooo0P0000040?ooo`<00000
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L000006@3oool00`000000oooo
0?ooo`0X0?ooo`P000002P3oool00`000000oooo0?ooo`020?ooo`<00000103oool2000004l0oooo
001@0?ooo`8000001@3oool4000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool01P3o
ool7000001<0oooo00<000000?ooo`3oool08`3oool7000000l0oooo00<000000?ooo`0000000`00
00050?ooo`800000D@3oool00580oooo0P0000050?ooo`030000003oool00000008000001P3oool0
0`000000oooo0?ooo`070?ooo`8000000`3oool7000000d0oooo00<000000?ooo`3oool06`3oool7
000000<0oooo0P0000000`3oool000000?ooo`0=0?ooo`<0000000<0oooo0000003oool0103oool2
000005<0oooo001D0?ooo`800000103oool200000080oooo0`0000030?ooo`030000003oool0oooo
00T0oooo0P0000080?ooo`H000001`3oool00`000000oooo0?ooo`0E0?ooo`H00000203oool20000
00<0oooo00<000000?ooo`3oool02@3oool300000080oooo0P0000040?ooo`800000E@3oool005H0
oooo0P0000040?ooo`050000003oool0oooo0000003oool01000000=0?ooo`800000303oool70000
00030?ooo`000000oooo00h0oooo1`00000<0?ooo`8000001P3oool00`000000oooo0?ooo`050?oo
o`<0000000D0oooo0000003oool0oooo000000040?ooo`800000E`3oool005P0oooo0P0000030?oo
o`040000003oool0oooo000000<0oooo0`00000=0?ooo`8000004@3oool6000000D0oooo1P00000A
0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`<000000`3oool010000000oooo0?ooo`00
00030?ooo`800000F@3oool005X0oooo0P0000020?ooo`80000000<0oooo0000003oool00P3oool0
0`000000oooo00000003000000/0oooo0P00000A0?ooo`030000003oool0000000P000004`3oool2
000000/0oooo100000050?ooo`040000003oool0000000000080oooo0P00001K0?ooo`00G03oool2
00000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`<000002P3oool2
000000/0oooo1P0000090?ooo`H000002`3oool2000000X0oooo100000070?ooo`030000003oool0
00000080oooo0P00001M0?ooo`00GP3oool2000000040?ooo`000000000000000080oooo00<00000
0?ooo`3oool01@3oool3000000T0oooo0P0000020?ooo`L000001@3oool00`000000oooo0?ooo`0=
0?ooo`L000000P3oool2000000T0oooo0`0000040?ooo`030000003oool0oooo00<0oooo0`000000
0`3oool000000000001O0?ooo`00H03oool2000000040?ooo`00000000000?ooo`<00000203oool3
000000@0oooo1P00000<0?ooo`030000003oool0oooo01@0oooo1P0000040?ooo`<000001`3oool4
000000040?ooo`00000000000?ooo`800000H@3oool00680oooo200000070?ooo`L000001P3oool2
000000/0oooo00<000000?ooo`3oool04@3oool2000000H0oooo1`0000070?ooo`P00000H`3oool0
06@0oooo3@0000060?ooo`@000001@3oool2000000T0oooo00<000000?ooo`3oool03`3oool20000
00D0oooo100000060?ooo`d00000I@3oool006@0ooooE`00001U0?ooo`00I03oool=000000d0oooo
0`0000030?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`8000000`3oool3000000d0oooo
3@00001U0?ooo`00I@3oool5000000L0oooo1`0000090?ooo`<000000P3oool2000000D0oooo00<0
00000?ooo`3oool01`3oool200000080oooo0`0000090?ooo`L000001`3oool5000006H0oooo001V
0?ooo`<000003`3oool7000000D0oooo0`0000000`3oool00000000000030?ooo`030000003oool0
oooo00D0oooo0P000000103oool000000000000000050?ooo`L000003`3oool3000006L0oooo001o
0?ooo`H000000P3oool500000080oooo0`0000020?ooo`D000000P3oool600000800oooo00250?oo
oaD00000QP3oool008`0oooo1`00002=0?ooo`00S03oool7000008d0oooo002<0?ooo`L00000S@3o
ool008d0oooo1@00002>0?ooo`00SP3oool3000008l0oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500054, -0.0500054, \
0.00383279, 0.00383279}}]
}, Open  ]],

Cell["\<\
Das Rewiring-Verfahren l\[ADoubleDot]sst sich \[ADoubleDot]hnlich \
implementieren. Hier sind jedoch zwei Schwierigkeiten zu beachten: (1) Da zur \
Umverdrahtung nur die bestehenden Verbindungen herangezogen werden, muss die \
Schleife \[UDoubleDot]ber alle Einsen in der Adjacency-Matrix laufen. (2) Das \
Ende der bestehenden Verbindung muss aus der Matrix entfernt werden.\
\>", \
"Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[TextData[{
  StyleBox["Die Strategie ist, alle Operationen nur auf einer Dreiecksmatrix \
durchzuf\[UDoubleDot]hren und die Symmetrie der Matrix danach mit einer \
separaten Routine ",
    FontColor->GrayLevel[0.500008]],
  StyleBox["makeSymmetric",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.501961]],
  StyleBox[" wieder herzustellen.",
    FontColor->GrayLevel[0.500008]]
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    RowBox[{
      StyleBox[\(makeSymmetric[triag_]\  := \ 
          Module[{mm0, \ 
              mm1}, \n\ \ \ \ \ mm0\  = \ \(Dimensions[
                  triag]\)[\([1]\)]; \n\ \ \ \ \ mm1\  = \ 
              Table[0, \ {ii, \ 1, \ mm0}, \ {jj, \ 1, \ 
                  mm0}]; \n\ \ \ \ \ Do[
              mm1[\([jj, \ ii]\)]\  = \ triag[\([ii, \ jj]\)], \ {ii, \ 1, \ 
                mm0}, \ {jj, \ 1, \ ii\  - \ 1}]; \n\ \ \ \ \ Do[
              mm1[\([ii, \ jj]\)]\  = \ triag[\([ii, \ jj]\)], \ {ii, \ 1, \ 
                mm0}, \ {jj, \ 1, \ ii\  - \ 1}]; \n\ \ \ \ \ mm1]\),
        FormatType->StandardForm,
        FontFamily->"Courier New",
        FontSize->12,
        FontWeight->"Bold",
        FontSlant->"Plain",
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}], 
      StyleBox["\n",
        FormatType->StandardForm,
        FontFamily->"Arial",
        FontSize->10]}]], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(rewireSW[nn_, neigh_, prob_] := 
      Module[{bb1, bb2, bb3, bb4, bb5, bb6}, \[IndentingNewLine]bb1 = 
          backbone[nn, neigh]; \[IndentingNewLine]bb2 = 
          Flatten[Table[{ii, jj}, {ii, 1, nn}, {jj, 1, ii - 1}], 
            1]; \[IndentingNewLine]bb3 = Length[bb2]; \[IndentingNewLine]Do[
          If[bb1[\([ii, jj]\)] \[Equal] 1 && 
              Random[] < prob, {bb5 = bb2[\([Random[Integer, {1, bb3}]]\)], 
              bb1[\([ii, jj]\)] = 0, 
              bb1[\([bb5[\([1]\)], bb5[\([2]\)]]\)] = 1}], {ii, 1, nn}, {jj, 
            1, ii - 1}]; \[IndentingNewLine]bb6 = 
          makeSymmetric[
            Table[bb1[\([ii, jj]\)], {ii, 1, nn}, {jj, 1, 
                ii - 1}]]]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[TextData[{
  "Kehren wir noch einmal zum Graphen ",
  StyleBox["g1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " zur\[UDoubleDot]ck. Der Befehl ",
  StyleBox["Distances[g1, i]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " liefert die Abst\[ADoubleDot]nde aller Knoten des Graphen ",
  StyleBox["g1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " zum ",
  StyleBox["i",
    FontSlant->"Italic"],
  "ten Knoten."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Distances[g1, 1]\)], "Input"],

Cell[BoxData[
    \({0, 1, 1, 1, 1, 2, 2, 2, 2, 2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Dieser Befehl l\[ADoubleDot]sst sich ausnutzen, um die mittlere Wegl\
\[ADoubleDot]nge in dem Graphen zu bestimmen. Dies ist als Routine ",
  StyleBox["averagePathLength",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " hier angegeben. "
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(averagePathLength[g_] := N[Plus @@ Eccentricity[g]/V[g]]\)], "Input",
  FontFamily->"Courier New",
  FontColor->GrayLevel[0.500008]],

Cell[TextData[{
  "Wir werden f\[UDoubleDot]r Small-World-Graphen diese Gr\[ODoubleDot]\[SZ]e \
gleich als Funktion der Rewiring-Wahrscheinlichkeit ",
  StyleBox["p",
    FontSlant->"Italic"],
  " diskutieren. Zuvor wollen wir uns aber einer zweiten zur \
Charakterisierung von Small-World-Graphen wichtigen Eigenschaft - neben der \
Wegl\[ADoubleDot]nge - zuwenden: dem Clusterkoeffizienten. Daf\[UDoubleDot]r \
legen wir zuerst eine Liste der Ausdr\[UDoubleDot]cke",
  StyleBox[" k (k - 1)",
    FontSlant->"Italic"],
  " an, die bei der Berechnung des Clusterkoeffizienten auftreten. Der Befehl \
",
  StyleBox["Degrees",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " gibt die Liste von Graden an:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Degrees[g1]\)], "Input"],

Cell[BoxData[
    \({4, 5, 7, 7, 4, 4, 6, 7, 5, 5}\)], "Output"]
}, Open  ]],

Cell["\<\
Da die Multiplikation von Listen elementweise erfolgt, kann man nun \
einfach schreiben:\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Degrees[g1] \((Degrees[g1] - 1)\)\)], "Input"],

Cell[BoxData[
    \({12, 20, 42, 42, 12, 12, 30, 42, 20, 20}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Zudem legen wir in der Routine f\[UDoubleDot]r den Clusterkoeffizienten \
die Adjacency-Matrix und die Zahl der Knoten in Hilfsvariablen ab. Dann \
durchlaufen wir alle Zeilen der Adjacency-Matrix, ermitteln die Positionen \
von Einsen und legen Listen von Einsen in den zugeh\[ODoubleDot]rigen Zeilen \
an. Dies sind die Verbindungen unter den direkten Nachbarn eines Knotens. \
Diese Zahl teilen wir durch 0.5 ",
  StyleBox["k (k - 1)",
    FontSlant->"Italic"],
  ", bilden den Mittelwert und erhalten so den mittleren Clusterkoeffizienten \
dieses Graphen:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(clusterCoeff[gX_] := 
      Module[{xx0, xx1, xx2, xx3, xx4, xx5, xx6}, \[IndentingNewLine]xx1 = 
          Degrees[gX] \((Degrees[gX] - 1)\); \[IndentingNewLine]xx2 = 
          ToAdjacencyMatrix[gX]; \[IndentingNewLine]xx0 = 
          Length[xx2]; \[IndentingNewLine]Do[{xx3 = 
              Flatten[Outer[List, Flatten[Position[xx2[\([kk]\)], 1]], 
                  Flatten[Position[xx2[\([kk]\)], 1]]], 
                1], \[IndentingNewLine]xx4 = 
              Table[xx2[\([xx3[\([jj, 1]\)], xx3[\([jj, 2]\)]]\)], {jj, 1, 
                  Length[xx3]}], \[IndentingNewLine]clX[kk] = 
              Count[xx4, 1]}, {kk, 1, xx0}]; \[IndentingNewLine]xx7 = 
          Table[clX[kk], {kk, 1, xx0}]; \[IndentingNewLine]xx5 = 
          Table[If[xx1[\([jj]\)] \[Equal] 0, 0, 
              N[2*xx7[\([jj]\)]/xx1[\([jj]\)]]], {jj, 1, 
              xx0}]; \[IndentingNewLine]xx6 = 
          N[Plus @@ xx5/\((2*xx0)\)]]\)], "Input"],

Cell[TextData[{
  "F\[UDoubleDot]r d",
  "en Zufallsgraphen ",
  StyleBox["g1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " erh\[ADoubleDot]lt man:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(clusterCoeff[g1]\)], "Input"],

Cell[BoxData[
    \(0.5885714285714285`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Diese Routine und die Wegl\[ADoubleDot]ngenbestimmung k\[ODoubleDot]nnen \
wir nun nutzen, um die Eigenschaften solcher Small-World-Graphen in Abh\
\[ADoubleDot]ngigkeit der Rewiring-Wahrscheinlichkeit ",
  StyleBox["p",
    FontSlant->"Italic"],
  " besser zu verstehen. Dies leistet die folgende ",
  StyleBox["Do",
    FontSlant->"Italic"],
  "-Schleife."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[{Print[
          N[10^pp]], \(gX1 = 
            FromAdjacencyMatrix[rewireSW[100, 4, N[10^pp]]];\), 
        clustX[pp] = clusterCoeff[gX1], \[IndentingNewLine]distX[pp] = 
          averagePathLength[gX1]}, {pp, \(-3\), 0, 0.05}]\)], "Input"],

Cell[BoxData[
    \(0.001`\)], "Print"],

Cell[BoxData[
    \(0.001122018454301963`\)], "Print"],

Cell[BoxData[
    \(0.0012589254117941675`\)], "Print"],

Cell[BoxData[
    \(0.001412537544622754`\)], "Print"],

Cell[BoxData[
    \(0.001584893192461114`\)], "Print"],

Cell[BoxData[
    \(0.0017782794100389228`\)], "Print"],

Cell[BoxData[
    \(0.001995262314968879`\)], "Print"],

Cell[BoxData[
    \(0.00223872113856834`\)], "Print"],

Cell[BoxData[
    \(0.0025118864315095794`\)], "Print"],

Cell[BoxData[
    \(0.002818382931264455`\)], "Print"],

Cell[BoxData[
    \(0.0031622776601683794`\)], "Print"],

Cell[BoxData[
    \(0.0035481338923357532`\)], "Print"],

Cell[BoxData[
    \(0.003981071705534973`\)], "Print"],

Cell[BoxData[
    \(0.0044668359215096305`\)], "Print"],

Cell[BoxData[
    \(0.005011872336272725`\)], "Print"],

Cell[BoxData[
    \(0.005623413251903491`\)], "Print"],

Cell[BoxData[
    \(0.00630957344480193`\)], "Print"],

Cell[BoxData[
    \(0.00707945784384138`\)], "Print"],

Cell[BoxData[
    \(0.007943282347242814`\)], "Print"],

Cell[BoxData[
    \(0.008912509381337459`\)], "Print"],

Cell[BoxData[
    \(0.01`\)], "Print"],

Cell[BoxData[
    \(0.011220184543019636`\)], "Print"],

Cell[BoxData[
    \(0.012589254117941675`\)], "Print"],

Cell[BoxData[
    \(0.014125375446227547`\)], "Print"],

Cell[BoxData[
    \(0.01584893192461114`\)], "Print"],

Cell[BoxData[
    \(0.01778279410038923`\)], "Print"],

Cell[BoxData[
    \(0.0199526231496888`\)], "Print"],

Cell[BoxData[
    \(0.0223872113856834`\)], "Print"],

Cell[BoxData[
    \(0.025118864315095808`\)], "Print"],

Cell[BoxData[
    \(0.02818382931264455`\)], "Print"],

Cell[BoxData[
    \(0.03162277660168379`\)], "Print"],

Cell[BoxData[
    \(0.03548133892335755`\)], "Print"],

Cell[BoxData[
    \(0.039810717055349734`\)], "Print"],

Cell[BoxData[
    \(0.04466835921509633`\)], "Print"],

Cell[BoxData[
    \(0.05011872336272725`\)], "Print"],

Cell[BoxData[
    \(0.05623413251903491`\)], "Print"],

Cell[BoxData[
    \(0.06309573444801933`\)], "Print"],

Cell[BoxData[
    \(0.0707945784384138`\)], "Print"],

Cell[BoxData[
    \(0.07943282347242818`\)], "Print"],

Cell[BoxData[
    \(0.08912509381337459`\)], "Print"],

Cell[BoxData[
    \(0.10000000000000002`\)], "Print"],

Cell[BoxData[
    \(0.11220184543019639`\)], "Print"],

Cell[BoxData[
    \(0.12589254117941676`\)], "Print"],

Cell[BoxData[
    \(0.14125375446227548`\)], "Print"],

Cell[BoxData[
    \(0.15848931924611143`\)], "Print"],

Cell[BoxData[
    \(0.17782794100389232`\)], "Print"],

Cell[BoxData[
    \(0.19952623149688803`\)], "Print"],

Cell[BoxData[
    \(0.223872113856834`\)], "Print"],

Cell[BoxData[
    \(0.25118864315095807`\)], "Print"],

Cell[BoxData[
    \(0.2818382931264455`\)], "Print"],

Cell[BoxData[
    \(0.316227766016838`\)], "Print"],

Cell[BoxData[
    \(0.3548133892335756`\)], "Print"],

Cell[BoxData[
    \(0.39810717055349737`\)], "Print"],

Cell[BoxData[
    \(0.44668359215096326`\)], "Print"],

Cell[BoxData[
    \(0.5011872336272725`\)], "Print"],

Cell[BoxData[
    \(0.5623413251903493`\)], "Print"],

Cell[BoxData[
    \(0.6309573444801935`\)], "Print"],

Cell[BoxData[
    \(0.7079457843841381`\)], "Print"],

Cell[BoxData[
    \(0.7943282347242818`\)], "Print"],

Cell[BoxData[
    \(0.8912509381337459`\)], "Print"],

Cell[BoxData[
    \(1.`\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "Die Auftragung der Gr\[ODoubleDot]\[SZ]en ",
  StyleBox["clustX",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " und ",
  StyleBox["distX",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " in Abh\[ADoubleDot]ngigkeit der Rewiring-Wahrscheinlichkeit ",
  StyleBox["p",
    FontSlant->"Italic"],
  " f\[UDoubleDot]hrt (im Wesentlichen) auf den unteren Teil von Abb. 5.29."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowSize->{507, 809},
WindowMargins->{{308, Automatic}, {Automatic, 12}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S5.20.1"->{
    Cell[4517, 136, 69, 1, 30, "Input",
      CellTags->"S5.20.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S5.20.1", 248856, 4139}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 553, 21, 115, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2332, 76, 176, 6, 97, "Subtitle"],
Cell[2511, 84, 1949, 47, 395, "Text"],
Cell[4463, 133, 51, 1, 30, "Input"],
Cell[4517, 136, 69, 1, 30, "Input",
  CellTags->"S5.20.1"],
Cell[4589, 139, 63, 1, 30, "Input"],
Cell[4655, 142, 227, 9, 34, "Text"],

Cell[CellGroupData[{
Cell[4907, 155, 57, 1, 30, "Input"],
Cell[4967, 158, 81071, 1116, 296, 1674, 131, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[86053, 1277, 161, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[86239, 1286, 116, 2, 50, "Input"],
Cell[86358, 1290, 910, 18, 169, "Output"]
}, Open  ]],
Cell[87283, 1311, 889, 29, 130, "Text"],

Cell[CellGroupData[{
Cell[88197, 1344, 47, 1, 30, "Input"],
Cell[88247, 1347, 38, 1, 29, "Output"]
}, Open  ]],
Cell[88300, 1351, 762, 19, 148, "Text"],

Cell[CellGroupData[{
Cell[89087, 1374, 357, 6, 110, "Input"],
Cell[89447, 1382, 159, 3, 25, "Print"],
Cell[89609, 1387, 161, 3, 25, "Print"],
Cell[89773, 1392, 161, 3, 25, "Print"],
Cell[89937, 1397, 177, 3, 25, "Print"],
Cell[90117, 1402, 177, 3, 25, "Print"],
Cell[90297, 1407, 177, 3, 25, "Print"],
Cell[90477, 1412, 177, 3, 25, "Print"],
Cell[90657, 1417, 177, 3, 25, "Print"],
Cell[90837, 1422, 177, 3, 25, "Print"],
Cell[91017, 1427, 177, 3, 25, "Print"],
Cell[91197, 1432, 175, 3, 25, "Print"]
}, Open  ]],
Cell[91387, 1438, 2051, 62, 301, "Text"],

Cell[CellGroupData[{
Cell[93463, 1504, 69, 1, 30, "Input"],
Cell[93535, 1507, 79, 1, 29, "Output"]
}, Open  ]],
Cell[93629, 1511, 338, 7, 90, "Text"],
Cell[93970, 1520, 363, 6, 130, "Input"],
Cell[94336, 1528, 216, 6, 52, "Text"],

Cell[CellGroupData[{
Cell[94577, 1538, 142, 3, 50, "Input"],
Cell[94722, 1543, 66083, 939, 296, 1764, 140, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[160820, 2485, 1109, 19, 261, "Text"],
Cell[161932, 2506, 376, 7, 150, "Input"],
Cell[162311, 2515, 620, 15, 128, "Text"],

Cell[CellGroupData[{
Cell[162956, 2534, 161, 4, 50, "Input"],
Cell[163120, 2540, 73222, 1134, 296, 3124, 264, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[236357, 3677, 450, 9, 109, "Text"],
Cell[236810, 3688, 497, 14, 72, "Text"],
Cell[237310, 3704, 986, 23, 190, "Input"],
Cell[238299, 3729, 771, 14, 250, "Input"],
Cell[239073, 3745, 576, 22, 73, "Text"],

Cell[CellGroupData[{
Cell[239674, 3771, 49, 1, 30, "Input"],
Cell[239726, 3774, 64, 1, 29, "Output"]
}, Open  ]],
Cell[239805, 3778, 347, 10, 72, "Text"],
Cell[240155, 3790, 152, 3, 30, "Input"],
Cell[240310, 3795, 794, 20, 148, "Text"],

Cell[CellGroupData[{
Cell[241129, 3819, 44, 1, 30, "Input"],
Cell[241176, 3822, 64, 1, 29, "Output"]
}, Open  ]],
Cell[241255, 3826, 161, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[241441, 3835, 66, 1, 30, "Input"],
Cell[241510, 3838, 74, 1, 29, "Output"]
}, Open  ]],
Cell[241599, 3842, 641, 13, 147, "Text"],
Cell[242243, 3857, 956, 16, 370, "Input"],
Cell[243202, 3875, 243, 10, 34, "Text"],

Cell[CellGroupData[{
Cell[243470, 3889, 49, 1, 30, "Input"],
Cell[243522, 3892, 53, 1, 29, "Output"]
}, Open  ]],
Cell[243590, 3896, 438, 12, 90, "Text"],

Cell[CellGroupData[{
Cell[244053, 3912, 268, 5, 110, "Input"],
Cell[244324, 3919, 39, 1, 25, "Print"],
Cell[244366, 3922, 54, 1, 25, "Print"],
Cell[244423, 3925, 55, 1, 25, "Print"],
Cell[244481, 3928, 54, 1, 25, "Print"],
Cell[244538, 3931, 54, 1, 25, "Print"],
Cell[244595, 3934, 55, 1, 25, "Print"],
Cell[244653, 3937, 54, 1, 25, "Print"],
Cell[244710, 3940, 53, 1, 25, "Print"],
Cell[244766, 3943, 55, 1, 25, "Print"],
Cell[244824, 3946, 54, 1, 25, "Print"],
Cell[244881, 3949, 55, 1, 25, "Print"],
Cell[244939, 3952, 55, 1, 25, "Print"],
Cell[244997, 3955, 54, 1, 25, "Print"],
Cell[245054, 3958, 55, 1, 25, "Print"],
Cell[245112, 3961, 54, 1, 25, "Print"],
Cell[245169, 3964, 54, 1, 25, "Print"],
Cell[245226, 3967, 53, 1, 25, "Print"],
Cell[245282, 3970, 53, 1, 25, "Print"],
Cell[245338, 3973, 54, 1, 25, "Print"],
Cell[245395, 3976, 54, 1, 25, "Print"],
Cell[245452, 3979, 38, 1, 25, "Print"],
Cell[245493, 3982, 54, 1, 25, "Print"],
Cell[245550, 3985, 54, 1, 25, "Print"],
Cell[245607, 3988, 54, 1, 25, "Print"],
Cell[245664, 3991, 53, 1, 25, "Print"],
Cell[245720, 3994, 53, 1, 25, "Print"],
Cell[245776, 3997, 52, 1, 25, "Print"],
Cell[245831, 4000, 52, 1, 25, "Print"],
Cell[245886, 4003, 54, 1, 25, "Print"],
Cell[245943, 4006, 53, 1, 25, "Print"],
Cell[245999, 4009, 53, 1, 25, "Print"],
Cell[246055, 4012, 53, 1, 25, "Print"],
Cell[246111, 4015, 54, 1, 25, "Print"],
Cell[246168, 4018, 53, 1, 25, "Print"],
Cell[246224, 4021, 53, 1, 25, "Print"],
Cell[246280, 4024, 53, 1, 25, "Print"],
Cell[246336, 4027, 53, 1, 25, "Print"],
Cell[246392, 4030, 52, 1, 25, "Print"],
Cell[246447, 4033, 53, 1, 25, "Print"],
Cell[246503, 4036, 53, 1, 25, "Print"],
Cell[246559, 4039, 53, 1, 25, "Print"],
Cell[246615, 4042, 53, 1, 25, "Print"],
Cell[246671, 4045, 53, 1, 25, "Print"],
Cell[246727, 4048, 53, 1, 25, "Print"],
Cell[246783, 4051, 53, 1, 25, "Print"],
Cell[246839, 4054, 53, 1, 25, "Print"],
Cell[246895, 4057, 53, 1, 25, "Print"],
Cell[246951, 4060, 51, 1, 25, "Print"],
Cell[247005, 4063, 53, 1, 25, "Print"],
Cell[247061, 4066, 52, 1, 25, "Print"],
Cell[247116, 4069, 51, 1, 25, "Print"],
Cell[247170, 4072, 52, 1, 25, "Print"],
Cell[247225, 4075, 53, 1, 25, "Print"],
Cell[247281, 4078, 53, 1, 25, "Print"],
Cell[247337, 4081, 52, 1, 25, "Print"],
Cell[247392, 4084, 52, 1, 25, "Print"],
Cell[247447, 4087, 52, 1, 25, "Print"],
Cell[247502, 4090, 52, 1, 25, "Print"],
Cell[247557, 4093, 52, 1, 25, "Print"],
Cell[247612, 4096, 52, 1, 25, "Print"],
Cell[247667, 4099, 36, 1, 25, "Print"]
}, Open  ]],
Cell[247718, 4103, 510, 17, 72, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

